@@ -79,7 +79,7 @@ static int getfid (char *path, ViceFid *Fid, ViceVersionVector *VV, struct ViceI
     vi->out = buf;
     vi->out_size = sizeof(buf);
                       
-    if (pioctl(path, VIOC_GETFID, vi, 0)) {
+    if (pioctl(path, _VICEIOCTL(_VIOC_GETFID), vi, 0)) {
 	char symval[MAXPATHLEN];
 	symval[0] = 0;
 	if (errno != ENOENT){
@@ -172,7 +172,7 @@ struct Acl *res_getacl (char *path)
     vi.in = 0;
     vi.out = AclBuf;
     vi.out_size = sizeof(AclBuf);
-    if (pioctl(path, VIOCGETAL, &vi, 0)){
+    if (pioctl(path, _VICEIOCTL(_VIOCGETAL), &vi, 0)){
 	perror("pioctl: GETAL");
 	if (errno == EINVAL) {
 	    printf("can not get ACL on fake object %s\n", path);
@@ -354,7 +354,8 @@ int InsertListHdr (struct repair *rep, struct listhdr **ops, int index)
 }
 
 /* checks if an entry exists in a repair list */
-int InRepairList (struct listhdr *opList, unsigned opcode, long vnode, long unique)
+int InRepairList (struct listhdr *opList, unsigned opcode,
+		  VnodeId vnode, Unique_t unique)
 {
     struct repair *repList = opList->repairList;
 
@@ -365,7 +366,7 @@ int InRepairList (struct listhdr *opList, unsigned opcode, long vnode, long uniq
 }
 
 /* checks if a fid has been created by an earlier operation in a repair list */
-int IsCreatedEarlier (struct listhdr **opList, int index, long vnode, long unique)
+int IsCreatedEarlier (struct listhdr **opList, int index, VnodeId vnode, Unique_t unique)
 {
     struct repair *repList = (*opList)[index].repairList;
     unsigned int count = (*opList)[index].repairCount;
@@ -454,7 +455,7 @@ int NameNameResolve(int first, int last, int nreplicas, resreplica *dirs, struct
     
     for (i = first; i < last; i++) {
 	resdir_entry *rde = sortedArrByName[i];
-	printf("%s%s\n\tFid: (%lx.%lx) VV:(%ld %ld %ld %ld %ld %ld %ld %ld)(%x.%x)\n",
+	printf("%s%s\n\tFid: (%lx.%lx) VV:(%ld %ld %ld %ld %ld %ld %ld %ld)(%lx.%lx)\n",
 	       dirs[rde->replicaid].path, sortedArrByName[first]->name,
 	       rde->vno, rde->uniqfier, rde->VV.Versions.Site0,
 	       rde->VV.Versions.Site1, rde->VV.Versions.Site2, rde->VV.Versions.Site3,
@@ -673,7 +674,7 @@ int GetParent(char *realm, ViceFid *cfid, ViceFid *dfid, char *volmtpt, char *dp
     memset(tmp, 0, sizeof(tmp));
 
     strcpy(path, "/coda");
-    rc = pioctl(path, VIOC_GETPATH, &vi, 0);
+    rc = pioctl(path, _VICEIOCTL(_VIOC_GETPATH), &vi, 0);
     if (rc) {
 	//printf("GetParent: Getpath returns error %d, errno = %d\n",
 	//rc, errno);
@@ -715,7 +716,7 @@ int GetParent(char *realm, ViceFid *cfid, ViceFid *dfid, char *volmtpt, char *dp
     vi.out = tmp;
     vi.out_size = sizeof(tmp);
     strcpy(path, "/coda");
-    rc = pioctl(path, VIOC_GETPFID, &vi, 0);
+    rc = pioctl(path, _VICEIOCTL(_VIOC_GETPFID), &vi, 0);
     if (rc) {
 	printf("Error %d occured while trying to get fid of %s's parent\n", rc, childname);
 	return(rc);
