@@ -75,12 +75,12 @@ static int ReadGlobalState(int fd) {
 	return 0;
     }
 
-    if (norton_debug) printf("Read maximum vol ID: 0x%x\n", maxvolid);
+    if (norton_debug) printf("Read maximum vol ID: 0x%lx\n", maxvolid);
 
     rvmlib_begin_transaction(restore);
     VSetMaxVolumeId(maxvolid);
     rvmlib_end_transaction(flush, &(status));
-    if (norton_debug) printf("Set max vol id to 0x%08x.  RVM Status = %d\n",
+    if (norton_debug) printf("Set max vol id to 0x%08lx.  RVM Status = %d\n",
 		      maxvolid, status);
     return 1;
 }
@@ -347,7 +347,7 @@ static int DumpVnodeList(int fd, struct VolumeData *vol, int vol_index,
 
     nvnodes = v_index.vnodes();
     if (norton_debug) {
-	printf("Volume 0x%x, has %d %s vnodes\n", vol->volumeInfo->id,
+	printf("Volume 0x%lx, has %d %s vnodes\n", vol->volumeInfo->id,
 	       nvnodes, VNODECLASS(vclass));
     }
     
@@ -378,7 +378,7 @@ static int DumpVnodeList(int fd, struct VolumeData *vol, int vol_index,
 	    for (npages = 0; inode->di_pages[npages]; npages++);
 
 	    if (norton_debug) {
-		printf("    Inode %d has %d pages\n", inode, npages);
+		printf("    Inode %p has %d pages\n", inode, npages);
 	    }
 	    
 	    if (write(fd, (void *)&npages, (int)sizeof(npages)) == -1) {
@@ -469,7 +469,7 @@ static int ReadVnodeList(int fd, Volume *vp, VnodeClass vclass, int ResOn) {
 	    perror("Reading vnode number\n");
 	    return 0;
 	}
-	if (norton_debug) printf("Reading vnode number 0x%x\n", vnode_num);
+	if (norton_debug) printf("Reading vnode number 0x%lx\n", vnode_num);
 
 	memset((void *)(void *)vnode, 0, VNODESIZE(vclass));
 	
@@ -585,6 +585,7 @@ static int ReadVolVnodes(int fd, Volume *vp, int ResOn) {
 }
 
 
+#ifdef UNUSED
 static void NortonSetupVolume(VolHead *vh, Volume *vp, int volindex)
 {
     // This turns out to be a global since its static, but if the
@@ -600,12 +601,13 @@ static void NortonSetupVolume(VolHead *vh, Volume *vp, int volindex)
     vp->header = &header;
     vp->vol_index = volindex;
 }
+#endif
 
 // Can't re-use code in vol-salvage since this comes from command line.
 static void GetSkipVols(int num, VolumeId *ids, char *vol_nums[]) {
     while(num > 0) {
-	sscanf(*vol_nums, "%x", ids);
-	printf("Skipping volume: 0x%x\n", *ids);
+	sscanf(*vol_nums, "%lx", ids);
+	printf("Skipping volume: 0x%lx\n", *ids);
 	vol_nums++;
 	ids++;
 	num--;
@@ -645,7 +647,7 @@ static int HasBackVols(VolumeId *skipvols, int nskipvols) {
 		continue;
 	    } else {
 		ret = TRUE;
-		printf("backup volume: %s(0x%x)\n",
+		printf("backup volume: %s(0x%lx)\n",
 		       vol->data.volumeInfo->name,
 		       vol->data.volumeInfo->id);
 	    }
@@ -695,12 +697,12 @@ static int load_server_state(char *dump_file, VolumeId *skipvols, int nskipvols)
 	}
 
 	if (InSkipVolumeList(vol_head.header.id, skipvols, nskipvols)) {
-	    printf("Skipping volume 0x%x\n", vol_head.header.id);
+	    printf("Skipping volume 0x%lx\n", vol_head.header.id);
 	    SkipToNextVolHead(dump_fd);
 	    continue;
 	}
 	else
-	    printf("Reading volume 0x%x\n", vol_head.header.id);
+	    printf("Reading volume 0x%lx\n", vol_head.header.id);
 
 	rvmlib_begin_transaction(restore);
 
@@ -869,7 +871,7 @@ static int dump_server_state(char *dump_file, VolumeId *skipvols, int nskipvols)
 	  continue;
 	}
 	    
-	printf("Writing volume 0x%x\n", vol->data.volumeInfo->id);
+	printf("Writing volume 0x%lx\n", vol->data.volumeInfo->id);
 
 	if (!DumpVolHead(dump_fd, vol) ||
 	    !DumpVolDiskData(dump_fd, vol->data.volumeInfo) ||
