@@ -82,7 +82,6 @@ extern void SFTP_Activate (SFTP_Initializer *initPtr);
 #include "adv_daemon.h"
 
 int COPModes = 6;	/* ASYNCCOP2 | PIGGYCOP2 */
-int UseMulticast = 0;
 char myHostName[MAXHOSTNAMELEN];
 int rpc2_retries = UNSET_RT;
 int rpc2_timeout = UNSET_TO;
@@ -122,8 +121,6 @@ int srvent::deallocs = 0;
 
 void CommInit() {
     /* Initialize unset command-line parameters. */
-    if (rpc2_retries == UNSET_RT) rpc2_retries = DFLT_RT;
-    if (rpc2_timeout == UNSET_TO) rpc2_timeout = DFLT_TO;
     if (sftp_windowsize == UNSET_WS) sftp_windowsize = DFLT_WS;
     if (sftp_sendahead == UNSET_SA) sftp_sendahead = DFLT_SA;
     if (sftp_ackpoint == UNSET_AP) sftp_ackpoint = DFLT_AP;
@@ -173,7 +170,7 @@ void CommInit() {
     sei.AckPoint = sftp_ackpoint;
     sei.PacketSize = sftp_packetsize;
     sei.EnforceQuota = 1;
-    sei.Port.Tag = (enum PortTag)0;
+    sei.Port.Tag = (PortTag)0;
     SFTP_Activate(&sei);
 
     /* RPC2 initialization. */
@@ -211,11 +208,9 @@ int srvent::GetConn(connent **cpp, uid_t uid, int Force)
 	/* Check whether there is already a free connection. */
 	struct ConnKey Key; Key.host = host; Key.uid = uid;
 	conn_iterator next(&Key);
-	int count = 0;
 	while ((c = next())) {
-	    count++;
-	    if (!c->inuse) {
-		c->inuse = 1;
+	    if (!c->HasRef()) {
+		c->GetRef();
                 *cpp = c;
                 return 0;
 	    }
@@ -239,7 +234,7 @@ int srvent::GetConn(connent **cpp, uid_t uid, int Force)
     c = new connent(this, uid, ConnHandle, auth);
     if (!c) return(ENOMEM);
 
-    c->inuse = 1;
+    c->GetRef();
     connent::conntab->insert(&c->tblhandle);
     *cpp = c;
     return(0);
@@ -258,16 +253,15 @@ void PutConn(connent **cpp)
     LOG(100, ("PutConn: host = %s, uid = %d, cid = %d, auth = %d\n",
 	      c->srv->Name(), c->uid, c->connid, c->authenticated));
 
-    if (!c->inuse)
+    if (!c->HasRef())
 	{ c->print(logFile); CHOKE("PutConn: conn not in use"); }
 
     if (c->dying) {
 	connent::conntab->remove(&c->tblhandle);
 	delete c;
     }
-    else {
-	c->inuse = 0;
-    }
+    else
+	c->PutRef();
 }
 
 
@@ -341,9 +335,9 @@ int connent::Suicide(int disconnect)
     dying = 1;
 
     /* Can't do any more if it is busy. */
-    if (inuse) return(0);
+    if (HasRef()) return(0);
 
-    inuse = 1;
+    GetRef();
 
     /* Be nice and disconnect if requested. */
     if (disconnect) {
@@ -427,7 +421,7 @@ int connent::CheckResult(int code, VolumeId vid, int TranslateEINCOMP) {
 
 
 void connent::print(int fd) {
-    fdprint(fd, "%#08x : host = %s, uid = %d, cid = %d, auth = %d, inuse = %d, dying = %d\n",
+    fdprint(fd, "%#08x : host = %s, uid = %d, cid = %d, auth = %d, inuse = %u, dying = %d\n",
 	     (long)this, srv->Name(), uid, connid, authenticated, inuse, dying);
 }
 
@@ -445,7 +439,7 @@ connent *conn_iterator::operator()() {
 	if (key == (struct ConnKey *)0) return(c);
 	if ((key->host.s_addr == c->srv->host.s_addr ||
              key->host.s_addr == INADDR_ANY) &&
-	    (key->uid == c->uid || key->uid == ALL_UIDS))
+	    (key->uid == c->uid || key->uid == ANYUSER_UID))
 	    return(c);
     }
 
@@ -1052,13 +1046,15 @@ void srvent::Reset()
 
     /* Kill all direct connections to this server. */
     {
-	struct ConnKey Key; Key.host = host; Key.uid = ALL_UIDS;
+	struct ConnKey Key; Key.host = host; Key.uid = ANYUSER_UID;
 	conn_iterator conn_next(&Key);
 	connent *c = 0;
 	connent *tc = 0;
 	for (c = conn_next(); c != 0; c = tc) {
 	    tc = conn_next();		/* read ahead */
+	    if (tc) tc->GetRef();
 	    (void)c->Suicide(0);
+	    if (tc) tc->PutRef();
 	}
     }
 
