@@ -84,12 +84,12 @@ extern unsigned long WCThresh;
 
 /*  *****  Constants  *****  */
 
-const int DFLT_RT = 4;			    /* rpc2 retries */
-const int UNSET_RT = -1;
-const int DFLT_TO = 15;			    /* rpc2 timeout */
-const int UNSET_TO = -1;
+const int DFLT_RT = 5;			    /* rpc2 retries */
+const int UNSET_RT = 0;
+const int DFLT_TO = 60;			    /* rpc2 timeout */
+const int UNSET_TO = 0;
 const int DFLT_WS = 32;			    /* sftp window size */
-const int UNSET_WS = -1;
+const int UNSET_WS = 0;
 const int DFLT_SA = 8;			    /* sftp send ahead */
 const int UNSET_SA = -1;
 const int DFLT_AP = 8;			    /* sftp ack point */
@@ -155,8 +155,8 @@ class connent {
     unsigned authenticated : 1;
 
     /* Dynamic state; varies with each call. */
-    unsigned inuse : 1;
     unsigned dying : 1;
+    unsigned int inuse;
 
     /* Constructors, destructors, and private utility routines. */
     connent(srvent *, uid_t, RPC2_Handle, int);
@@ -173,6 +173,9 @@ class connent {
 
     int	Suicide(int);		/* 1 --> dead, 0 --> dying */
     int CheckResult(int, VolumeId, int TranslateEINCOMP = 1);
+    void GetRef(void) { inuse++; }
+    void PutRef(void) { CODA_ASSERT(inuse); inuse--; }
+    int HasRef(void) { return inuse; }
 
     void print() { print(stdout); }
     void print(FILE *fp) { fflush(fp); print(fileno(fp)); }
@@ -319,7 +322,6 @@ class probeslave : public vproc {
 /*  *****  Variables  *****  */
 
 extern int COPModes;
-extern int UseMulticast;
 extern char myHostName[];
 extern int rpc2_retries;
 extern int rpc2_timeout;
