@@ -92,9 +92,6 @@ const int FSDB_MagicNumber = 3620289;
 const int FSDB_NBUCKETS = 2048;
 const int FSO_MagicNumber = 2687694;
 
-const int BLOCKS_PER_FILE = 24;			    /* rule of thumb */
-const int MIN_CF = MIN_CB / BLOCKS_PER_FILE;
-
 const int MAX_PIGGY_VALIDATIONS = 50;
 
 /* Priorities. */
@@ -225,8 +222,8 @@ class fsdb {
   public:
     fsobj *Find(const VenusFid *);
     /* rcode arg added for local repair */
-    int Get(fsobj **fso, VenusFid *fid, uid_t uid, int rights, char *comp=0,
-	    int *rcode=0, int GetInconsistent=0);
+    int Get(fsobj **fso, VenusFid *fid, uid_t uid, int rights, char *comp=NULL,
+	    int *rcode=NULL, int GetInconsistent=0);
     void Put(fsobj **);
     void Flush();
     void Flush(Volid *);
@@ -539,7 +536,7 @@ class fsobj {
     void DetachHdbBindings();
     void DetachHdbBinding(binding *, int =0);
     int PredetermineFetchState(int, int);
-    void SetFetchAllowed(enum HoardFetchState new_state)
+    void SetFetchAllowed(HoardFetchState new_state)
         { FetchAllowed = new_state; }
     int IsFetchAllowed()
         { if (FetchAllowed == HF_Fetch) 
@@ -547,7 +544,7 @@ class fsobj {
           else 
               return 0; 
         }
-    void SetAskingAllowed(enum HoardAskState new_state)
+    void SetAskingAllowed(HoardAskState new_state)
         { AskingAllowed = new_state; }
     int IsAskingAllowed()
         { if (AskingAllowed == HA_Ask)
@@ -563,9 +560,6 @@ class fsobj {
     /* MLE Linkage. */
     void AttachMleBinding(binding *);
     void DetachMleBinding(binding *);
-#ifdef REMOVE_THIS
-    void CancelStores();
-#endif
 
     /* Data contents. */
     void DiscardData();
@@ -660,10 +654,10 @@ class fsobj {
     int SetVV(ViceVersionVector *, uid_t);
 
     /* The public CFS interface (non-Vice portion). */
-    int Open(int, int, int, venus_cnode *, uid_t);
+    int Open(int writep, int truncp, venus_cnode *cp, uid_t uid);
     int Sync(uid_t uid);
-    void Release(int writep, int execp);
-    int Close(int writep, int execp, uid_t uid);
+    void Release(int writep);
+    int Close(int writep, uid_t uid);
     int Access(long, int, uid_t);
     int Lookup(fsobj **, VenusFid *, char *, uid_t, int);
     int Readdir(char *, int, int, int *, uid_t);
@@ -712,6 +706,7 @@ class fsobj {
     void GetOperationState(int *, int *);                       /*N*/
     cmlent *FinalCmlent(int);                                   /*N*/
     void SetComp(char *);                                       /*U*/
+    const char *GetComp(void);
     void SetLocalObj();						/*T*/
     void UnsetLocalObj();					/*T*/
     int IsLocalObj() { return flags.local; }			/*N*/
@@ -791,16 +786,13 @@ extern void FSOD_Init(void);
 #define	DYING(f)	((f)->state == FsoDying)
 #define	READING(f)	(((f)->openers - (f)->Writers) > 0)
 #define	WRITING(f)	((f)->Writers > 0)
-#define	EXECUTING(f)	(EXECUTABLE(f) &&\
-			 !k_Purge(&(f)->fid))
-#define	BUSY(f)		((f)->refcnt > 0 ||\
-			 EXECUTING(f))
+#define	EXECUTING(f)	(EXECUTABLE(f) && READING(f) && !k_Purge(&(f)->fid))
+#define	ACTIVE(f)	(WRITING(f) || EXECUTING(f))
+#define	BUSY(f)		((f)->refcnt > 0 || EXECUTING(f))
 #define	HOARDABLE(f)	((f)->HoardPri > 0)
 #define	FETCHABLE(f)	(!DYING(f) &&\
-			 (HOARDING(f) ||\
-			  (LOGGING(f) && !DIRTY(f))) &&\
-			 (!HAVESTATUS(f) ||\
-			  (!WRITING(f) && !EXECUTING(f))))
+			 (HOARDING(f) || (LOGGING(f) && !DIRTY(f))) &&\
+			 (!HAVESTATUS(f) || !ACTIVE(f)))
 /* we are replaceable whenever we are linked into FSDB->prioq */
 #define	REPLACEABLE(f)	((f)->prio_handle.tree() != 0)
 #define	GCABLE(f)	(DYING(f) && !DIRTY(f) && !BUSY(f))
@@ -819,10 +811,10 @@ extern void FSOD_Init(void);
 
 #define	CFSOP_PRELUDE(str, comp, fid)\
 {\
-    char buf[256];\
-    strcpy(buf, (comp));\
-    if (buf[0] == '\0')\
-	sprintf(buf, "%s", FID_(&(fid)));\
+    char buf[CODA_MAXNAMLEN+1];\
+    if (comp && comp[0] != '\0')\
+	 strcpy(buf, comp);\
+    else sprintf(buf, "%s", FID_(&fid));\
     MarinerLog((str), buf);\
 }
 #define	CFSOP_POSTLUDE(str)\
