@@ -51,9 +51,6 @@ extern "C" {
 /* interfaces */
 #include <vcrcommon.h>
 
-/* from util */
-#include <proc.h>
-
 /* from venus */
 #include "advice.h"
 #include "adv_monitor.h"
@@ -507,13 +504,13 @@ int fsdb::Get(fsobj **f_addr, VenusFid *key, uid_t uid, int rights,
     int getdata = (rights & RC_DATA);
 
     LOG(100, ("fsdb::Get-mre: key = (%s), uid = %d, rights = %d, comp = %s\n",
-	       FID_(key), uid, rights, (comp ? comp : "")));
+	       FID_(key), uid, rights, comp));
 
     { 	/* a special check for accessing already localized object */
 	volent *vol = VDB->Find(MakeVolid(key));
 	if (vol && vol->IsReplicated()) {
 	    repvol *vp = (repvol *)vol;
-	    if (!vp->IsUnderRepair(ALL_UIDS) && vp->HasLocalSubtree()) {
+	    if (!vp->IsUnderRepair(ANYUSER_UID) && vp->HasLocalSubtree()) {
 		lgm_iterator next(LRDB->local_global_map);
 		lgment *lgm;
 		VenusFid *gfid;
@@ -631,7 +628,7 @@ RestartFind:
 	if (FID_IsLocalFake(key) || FID_IsFakeRoot(MakeViceFid(key))) {
 	    if (f->Fakeify()) {
 		LOG(0, ("fsdb::Get: can't transform %s (%s) into fake mt pt\n",
-			f->comp, FID_(&f->fid)));
+			f->GetComp(), FID_(&f->fid)));
 		Recov_BeginTrans();
 		f->Kill();
 		Recov_EndTrans(MAXFP);
@@ -667,12 +664,12 @@ RestartFind:
 	f->Lock(RD);
 
 	/* Update component. */
-	if (comp && comp[0] != '\0' && !STREQ(comp, ".") && !STREQ(comp, "..") && !STREQ(comp, f->comp)) {
-		Recov_BeginTrans();
-		RVMLIB_REC_OBJECT(f->comp);
-		rvmlib_rec_free(f->comp);
-		f->comp = rvmlib_strdup(comp);
-		Recov_EndTrans(MAXFP);
+	if (comp && comp[0] != '\0' &&
+	    !STREQ(comp, ".") && !STREQ(comp, "..") && !STREQ(comp, f->comp))
+	{
+	    Recov_BeginTrans();
+	    f->SetComp(comp);
+	    Recov_EndTrans(MAXFP);
 	}
     }
 
@@ -756,7 +753,7 @@ RestartFind:
 		     * the object here, otherwise Venus will think it is
 		     * "matriculating" and wait (forever) for it to finish.
 		     */
-		    eprint("%s (%s) inconsistent!", f->comp, FID_(&f->fid));
+		    eprint("%s (%s) inconsistent!", f->GetComp(), FID_(&f->fid));
 		    if (f->Fakeify()) {
 			Recov_BeginTrans();
 			f->Kill();
@@ -1089,7 +1086,7 @@ int fsdb::TranslateFid(VenusFid *OldFid, VenusFid *NewFid)
 	fsobj *f = 0;
 	VenusFid pFid;
 
-	LOG(100, ("fsdb::TranslateFid: %s --> %s", FID_(OldFid), 
+	LOG(100, ("fsdb::TranslateFid: %s --> %s\n", FID_(OldFid), 
 		  FID_(NewFid)));
 
 	/* cross volume replacements are for local fids */
@@ -1300,7 +1297,7 @@ void fsdb::ReclaimFsos(int priority, int count) {
 	/* Reclaim fso and data. */
 	MarinerLog("cache::Replace [%s] %s [%d, %d]\n",
 		   (HAVEDATA(f) ? "status/data" : "status"),
-		   f->comp, f->priority, NBLOCKS(f->cf.Length()));
+		   f->GetComp(), f->priority, NBLOCKS(f->cf.Length()));
 	UpdateCacheStats((f->IsDir() ? &DirAttrStats : &FileAttrStats),
 			 REPLACE, NBLOCKS(sizeof(fsobj)));
 	if (HAVEDATA(f))
@@ -1432,7 +1429,7 @@ void fsdb::ReclaimBlocks(int priority, int nblocks) {
 
 	/* Reclaim data.  Return if we've got enough. */
 	MarinerLog("cache::Replace [data] %s [%d, %d]\n",
-		   f->comp, f->priority, ufs_blocks);
+		   f->GetComp(), f->priority, ufs_blocks);
 	UpdateCacheStats((f->IsDir() ? &DirDataStats : &FileDataStats),
 			 REPLACE, BLOCKS(f));
 
