@@ -79,7 +79,7 @@ extern "C" {
 
 
 static int NullRcRights = 0;
-static AcRights NullAcRights = { ALL_UIDS, 0, 0, 0 };
+static AcRights NullAcRights = { ANYUSER_UID, 0, 0, 0 };
 
 
 /*  *****  Constructors, Destructors  *****  */
@@ -132,13 +132,7 @@ fsobj::fsobj(VenusFid *key, char *name) : cf() {
     RVMLIB_REC_OBJECT(*this);
     ResetPersistent();
     fid = *key;
-    {
-	int len = (name ? (int) strlen(name) : 0) + 1;
-	comp = (char *)rvmlib_rec_malloc(len);
-	rvmlib_set_range(comp, len);
-	if (name) strcpy(comp, name);
-	else comp[0] = '\0';
-    }
+    SetComp(name);
     if (FID_IsVolRoot(&fid))
 	mvstat = ROOT;
     ResetTransient();
@@ -155,7 +149,7 @@ fsobj::fsobj(VenusFid *key, char *name) : cf() {
 void fsobj::ResetPersistent() {
     MagicNumber = FSO_MagicNumber;
     fid = NullFid;
-    comp = 0;
+    comp = NULL;
     vol = 0;
     state = FsoRunt;
     stat.VnodeType = Invalid;
@@ -165,10 +159,10 @@ void fsobj::ResetPersistent() {
     stat.VV = NullVV;
     stat.VV.StoreId.Host = NO_HOST;
     stat.Date = (Date_t)-1;
-    stat.Author = ALL_UIDS;
-    stat.Owner = ALL_UIDS;
+    stat.Author = ANYUSER_UID;
+    stat.Owner = ANYUSER_UID;
     stat.Mode = (unsigned short)-1;
-    ClearAcRights(ALL_UIDS);
+    ClearAcRights(ANYUSER_UID);
     flags.fake = 0;
     flags.owrite = 0;
     flags.dirty = 0;
@@ -200,7 +194,7 @@ void fsobj::ResetTransient()
 	data.dir->udcf = 0;
     }
     ClearRcRights();
-    DemoteAcRights(ALL_UIDS);
+    DemoteAcRights(ANYUSER_UID);
     flags.ckmtpt = 0;
     flags.fetching = 0;
     flags.random = ::random();
@@ -345,16 +339,16 @@ fsobj::~fsobj() {
 	    CHOKE("fsobj::~fsobj: bogus mvstat");
     }
 
+    /* Release data. */
+    if (HAVEDATA(this))
+	DiscardData();
+
     /* Remove from volume's fso list */
     list_del(&vol_handle);
 
     /* Unlink from volume. */
     VDB->Put(&vol);
 
-    /* Release data. */
-    if (HAVEDATA(this))
-	DiscardData();
-
     /* Remove from the delete queue. */
     if (FSDB->delq->remove(&del_handle) != &del_handle)
 	{ print(logFile); CHOKE("fsobj::~fsobj: delq remove"); }
@@ -372,8 +366,10 @@ fsobj::~fsobj() {
     }
 
     /* Return component string to heap. */
-    rvmlib_rec_free(comp);
-    comp = NULL;
+    if (comp) {
+	rvmlib_rec_free(comp);
+	comp = NULL;
+    }
 }
 
 void fsobj::operator delete(void *deadobj, size_t len) {
@@ -453,7 +449,7 @@ void fsobj::Recover()
 	    int idx = 0;
 
 	    do {
-		snprintf(spoolfile,MAXPATHLEN,"%s/%s-%u",SpoolDir,comp,idx++);
+		snprintf(spoolfile,MAXPATHLEN,"%s/%s-%u",SpoolDir,GetComp(),idx++);
 	    } while (::access(spoolfile, F_OK) == 0 || errno != ENOENT); 
 
 	    data.file->Copy(spoolfile, NULL, 1);
@@ -595,7 +591,7 @@ void fsobj::Demote(void)
     ClearRcRights();
 
     if (IsDir())
-	DemoteAcRights(ALL_UIDS);
+	DemoteAcRights(ANYUSER_UID);
 
     DemoteHdbBindings();
 
@@ -649,6 +645,9 @@ int fsobj::Flush() {
 	}
     }
 
+    if (IsMtPt())
+	(void)u.root->Flush();
+
     if (!FLUSHABLE(this)) {
 	LOG(10, ("fsobj::Flush: (%s) !FLUSHABLE\n", FID_(&fid)));
 	Demote();
@@ -870,7 +869,7 @@ int fsobj::IsValid(int rcrights) {
 /* Returns {0, EACCES, ENOENT}. */
 int fsobj::CheckAcRights(uid_t uid, long rights, int connected)
 {
-    if (uid != ALL_UIDS) {
+    if (uid != ANYUSER_UID) {
 	/* Do we have this user's rights in the cache? */
 	for (int i = 0; i < CPSIZE; i++) {
 	    if (SpecificUser[i].inuse && (!connected || SpecificUser[i].valid)
@@ -878,7 +877,7 @@ int fsobj::CheckAcRights(uid_t uid, long rights, int connected)
 		return((rights & SpecificUser[i].rights) ? 0 : EACCES);
 	}
     }
-    if (uid == ALL_UIDS || !connected) {
+    if (uid == ANYUSER_UID || !connected) {
 	/* Do we have access via System:AnyUser? */
 	if (AnyUser.inuse && (!connected || AnyUser.valid))
 	    return((rights & AnyUser.rights) ? 0 : EACCES);
@@ -938,11 +937,11 @@ void fsobj::DemoteAcRights(uid_t uid)
 {
     LOG(100, ("fsobj::DemoteAcRights: (%s), uid = %d\n", FID_(&fid), uid));
 
-    if (uid == ALL_UIDS && AnyUser.valid)
+    if (uid == ANYUSER_UID)
 	AnyUser.valid = 0;
 
     for (int i = 0; i < CPSIZE; i++)
-	if ((uid == ALL_UIDS || SpecificUser[i].uid == uid) && SpecificUser[i].valid)
+	if (uid == ANYUSER_UID || SpecificUser[i].uid == uid)
 	    SpecificUser[i].valid = 0;
 }
 
@@ -952,7 +951,7 @@ void fsobj::PromoteAcRights(uid_t uid)
 {
     LOG(100, ("fsobj::PromoteAcRights: (%s), uid = %d\n", FID_(&fid), uid));
 
-    if (uid == ALL_UIDS) {
+    if (uid == ANYUSER_UID) {
 	AnyUser.valid = 1;
 
 	/* 
@@ -990,13 +989,13 @@ void fsobj::ClearAcRights(uid_t uid)
 {
     LOG(100, ("fsobj::ClearAcRights: (%s), uid = %d\n", FID_(&fid), uid));
 
-    if (uid == ALL_UIDS) {
+    if (uid == ANYUSER_UID) {
 	RVMLIB_REC_OBJECT(AnyUser);
 	AnyUser = NullAcRights;
     }
 
     for (int i = 0; i < CPSIZE; i++)
-	if (uid == ALL_UIDS || SpecificUser[i].uid == uid) {
+	if (uid == ANYUSER_UID || SpecificUser[i].uid == uid) {
 	    RVMLIB_REC_OBJECT(SpecificUser[i]);
 	    SpecificUser[i] = NullAcRights;
 	}
@@ -1189,7 +1188,7 @@ int fsobj::TryToCover(VenusFid *inc_fid, uid_t uid)
     fsobj *mf = rf->u.mtpoint;
     if (mf != 0) {
 	    if (mf == this) {
-		    eprint("TryToCover: re-mounting (%s) on (%s)", tvol->name, comp);
+		    eprint("TryToCover: re-mounting (%s) on (%s)", tvol->name, GetComp());
 		    UncoverMtPt();
 	    } else {
 		    if (mf->u.root != rf)
@@ -1873,19 +1872,6 @@ void fsobj::DetachMleBinding(binding *b) {
 }
 
 
-#ifdef REMOVE_THIS
-/* MUST NOT be called from within transaction! */
-void fsobj::CancelStores()
-{
-    if (!DIRTY(this))
-	{ print(logFile); CHOKE("fsobj::CancelStores: !DIRTY"); }
-
-    CODA_ASSERT(vol->IsReplicated());
-    ((repvol *)vol)->CancelStores(&fid);
-}
-#endif
-
-
 /*  *****  Data Contents  *****  */
 
 /* MUST be called from within transaction! */
@@ -1894,8 +1880,8 @@ void fsobj::CancelStores()
 void fsobj::DiscardData() {
     if (!HAVEDATA(this))
 	{ print(logFile); CHOKE("fsobj::DiscardData: !HAVEDATA"); }
-    if (WRITING(this) || EXECUTING(this))
-	{ print(logFile); CHOKE("fsobj::DiscardData: WRITING || EXECUTING"); }
+    if (ACTIVE(this))
+	{ print(logFile); CHOKE("fsobj::DiscardData: ACTIVE"); }
 
     LOG(10, ("fsobj::DiscardData: (%s)\n", FID_(&fid)));
 
@@ -1973,12 +1959,11 @@ int fsobj::Fakeify()
 
 		if (!pf->IsDir() || pf->IsMtPt()) continue;
 		if (!HAVEALLDATA(pf)) continue;
-		if (!pf->dir_IsParent(&fid)) continue;
 
-		/* Found! */
-		break;
+		if (pf->dir_IsParent(&fid))
+		    break; /* Found! */
 	    }
-	    if (!pf) {
+	    if (p == &vol->fso_list) {
 		LOG(0, ("fsobj::Fakeify: %s, (%s), parent not found\n",
 			comp, FID_(&fid)));
 		return(ENOENT);
@@ -2032,11 +2017,13 @@ int fsobj::Fakeify()
 	    }
 	    LOG(10, ("fsobj::Fakeify: created fake codaroot directory\n"));
 	} else {
+
 	    stat.Mode = 0644;
 	    stat.LinkCount = 1;
 	    stat.VnodeType = SymbolicLink;
 
 	    /* "#@RRRRRRRRR." */
+	    /* realm = comp */
 	    stat.Length = strlen(comp) + 3;
 	    data.symlink = (char *)rvmlib_rec_malloc(stat.Length+1);
 	    rvmlib_set_range(data.symlink, stat.Length+1);
