@@ -86,7 +86,7 @@ void fsobj::FetchProgressIndicator(unsigned long offset)
     }
 
     if (last != curr)
-	MarinerLog("progress::fetching (%s) %lu%%\n", comp, curr);
+	MarinerLog("progress::fetching (%s) %lu%%\n", GetComp(), curr);
 
     GotThisData = (unsigned long)offset;
 }
@@ -145,9 +145,12 @@ int fsobj::LookAside(void)
     if (fd != -1) {
 	memset(emsg, 0, sizeof(emsg));
 
-	lka_successful = LookAsideAndFillContainer(VenusSHA, fd,
-						   stat.Length, venusRoot,
-						   emsg, sizeof(emsg)-1);
+	/* lookaside always returns success for 0-length files, first of all
+	 * there really is nothing to fetch, and secondly we would otherwise
+	 * trigger the HAVEALLDATA assert in fsobj::Fetch */
+	lka_successful = LookAsideAndFillContainer(VenusSHA, fd, stat.Length,
+						   venusRoot, emsg,
+						   sizeof(emsg)-1);
 	data.file->Close(fd);
 
 	if (emsg[0])
@@ -162,10 +165,8 @@ int fsobj::LookAside(void)
     RVMLIB_REC_OBJECT(flags);
     flags.fetching = 0;
 
-    if (lka_successful) {
-	data.file->SetLength(stat.Length);
+    if (lka_successful)
 	cf.SetValidData(cf.Length()); 
-    }
     Recov_EndTrans(CMFP);
 
     /* If we received any callbacks during the lookaside, the validity of the
@@ -182,7 +183,7 @@ int fsobj::Fetch(uid_t uid)
 {
     int fd = -1;
 
-    LOG(10, ("fsobj::Fetch: (%s), uid = %d\n", comp, uid));
+    LOG(10, ("fsobj::Fetch: (%s), uid = %d\n", GetComp(), uid));
 
     CODA_ASSERT(!IsLocalObj());
 
@@ -541,7 +542,7 @@ NonRepExit:
 
 int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 {
-    LOG(10, ("fsobj::GetAttr: (%s), uid = %d\n", comp, uid));
+    LOG(10, ("fsobj::GetAttr: (%s), uid = %d\n", GetComp(), uid));
 
     CODA_ASSERT(!IsLocalObj());
 
@@ -756,7 +757,7 @@ int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 			    }
 
 		    LOG(10, ("fsobj::GetAttr: ValidateAttrs (%s), %d fids sent, %d checked\n",
-			      comp, numPiggyFids, numVFlags));
+			      GetComp(), numPiggyFids, numVFlags));
 
 		    nchecked += numPiggyFids;
 		    /* 
@@ -776,7 +777,7 @@ int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 			if (pobj) {
 			    if (VFlags[i] && HAVESTATUS(pobj)) {
 				LOG(1000, ("fsobj::GetAttr: ValidateAttrs (%s), fid (%s) valid\n",
-					  pobj->comp, FID_(&FAVs[i].Fid)));
+					  pobj->GetComp(), FID_(&FAVs[i].Fid)));
 				/* callbacks broken during validation make
 				 * any positive return codes suspect. */
 				if (cbtemp != cbbreaks) continue;
@@ -790,13 +791,13 @@ int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 				 * cached for this object are still good.
 				 */
 				if (pobj->IsDir()) {
-				    pobj->PromoteAcRights(ALL_UIDS);
+				    pobj->PromoteAcRights(ANYUSER_UID);
 				    pobj->PromoteAcRights(uid);
 				}
 			    } else {
 				/* invalidate status (and data) for this object */
 				LOG(1, ("fsobj::GetAttr: ValidateAttrs (%s), fid (%s) validation failed\n",
-					pobj->comp, FID_(&FAVs[i].Fid)));
+					pobj->GetComp(), FID_(&FAVs[i].Fid)));
 				
 				if (REPLACEABLE(pobj) && !BUSY(pobj)) {
 				    Recov_BeginTrans();
@@ -817,9 +818,9 @@ int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 				 * since the validation of piggybacked fids
 				 * is a side-effect.
 				 */
-				if (HAVEDATA(pobj) && !WRITING(pobj) &&
-				    !EXECUTING(pobj) && !pobj->IsFakeDir() ||
-				    DIRTY(pobj)) {
+				if (HAVEDATA(pobj) && !ACTIVE(pobj) &&
+				    !pobj->IsFakeDir() && !DIRTY(pobj))
+				{
 				    Recov_BeginTrans();
 				    UpdateCacheStats((IsDir() ? &FSDB->DirDataStats 
 						      : &FSDB->FileDataStats),
@@ -945,10 +946,11 @@ int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 
             ARG_UNMARSHALL_BS(myshavar, mysha, dh_ix);
 
-	    if (mysha.SeqLen == SHA_DIGEST_LENGTH) {
-		char printbuf[3*SHA_DIGEST_LENGTH+1];
+	    if (LogLevel >= 10 && mysha.SeqLen == SHA_DIGEST_LENGTH) {
+		char printbuf[2*SHA_DIGEST_LENGTH+1];
 		ViceSHAtoHex(mysha.SeqBody, printbuf, sizeof(printbuf));
-		LOG(-1, ("mysha(%d, %d) = %s\n.", mysha.MaxSeqLen, mysha.SeqLen, printbuf));
+		dprint("mysha(%d, %d) = %s\n.", mysha.MaxSeqLen, mysha.SeqLen,
+		       printbuf);
 	    }
 
 
@@ -1012,7 +1014,7 @@ int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 
 	if (IsFile()) {
 	    RVMLIB_REC_OBJECT(VenusSHA);
-	    /* VenusSHA already was set by getattr */
+	    /* VenusSHA already set by getattr */
 	    if (mysha.SeqLen != SHA_DIGEST_LENGTH)
 		memset(&VenusSHA, 0, SHA_DIGEST_LENGTH);
 	}
@@ -1170,7 +1172,7 @@ NonRepExit:
 
 int fsobj::GetACL(RPC2_BoundedBS *acl, uid_t uid)
 {
-    LOG(10, ("fsobj::GetACL: (%s), uid = %d\n", comp, uid));
+    LOG(10, ("fsobj::GetACL: (%s), uid = %d\n", GetComp(), uid));
 
     if (!HOARDING(this) && !LOGGING(this)) {
 	FSO_ASSERT(this, EMULATING(this));
@@ -1439,7 +1441,7 @@ Exit:
 
 int fsobj::Store(unsigned long NewLength, Date_t Mtime, uid_t uid)
 {
-    LOG(10, ("fsobj::Store: (%s), uid = %d\n", comp, uid));
+    LOG(10, ("fsobj::Store: (%s), uid = %d\n", GetComp(), uid));
 
     int code = 0;
 
@@ -1467,7 +1469,7 @@ int fsobj::Store(unsigned long NewLength, Date_t Mtime, uid_t uid)
 
 /* MUST be called from within transaction! */
 void fsobj::LocalSetAttr(Date_t Mtime, unsigned long NewLength,
-			  Date_t NewDate, uid_t NewOwner,
+			  Date_t NewDate, cuid_t NewOwner,
                           unsigned short NewMode)
 {
     /* Update local state. */
@@ -1741,7 +1743,7 @@ int fsobj::SetAttr(struct coda_vattr *vap, uid_t uid, RPC2_CountedBS *acl)
 	unsigned short NewMode = VA_IGNORE_MODE;
 
 
-	LOG(10, ("fsobj::SetAttr: (%s), uid = %d\n", comp, uid));
+	LOG(10, ("fsobj::SetAttr: (%s), uid = %d\n", GetComp(), uid));
 	VPROC_printvattr(vap);
     
 	if ( vap->va_size != VA_IGNORE_SIZE ) 
@@ -1811,7 +1813,7 @@ int fsobj::SetAttr(struct coda_vattr *vap, uid_t uid, RPC2_CountedBS *acl)
 
 int fsobj::SetACL(RPC2_CountedBS *acl, uid_t uid)
 {
-    LOG(10, ("fsobj::SetACL: (%s), uid = %d\n", comp, uid));
+    LOG(10, ("fsobj::SetACL: (%s), uid = %d\n", GetComp(), uid));
 
     if (!HOARDING(this)) {
 	FSO_ASSERT(this, (EMULATING(this) || LOGGING(this)));
@@ -2166,7 +2168,7 @@ int fsobj::Create(char *name, fsobj **target_fso_addr,
 		   uid_t uid, unsigned short Mode, int target_pri)
 {
     LOG(10, ("fsobj::Create: (%s, %s, %d), uid = %d\n",
-	      comp, name, target_pri, uid));
+	      GetComp(), name, target_pri, uid));
 
     int code = 0;
     Date_t Mtime = Vtime();
