@@ -72,10 +72,10 @@ extern "C" {
 
 /* Call with object write-locked. */
 /* MUST NOT be called from within a transaction. */
-int fsobj::Open(int writep, int execp, int truncp, venus_cnode *cp, uid_t uid) 
+int fsobj::Open(int writep, int truncp, venus_cnode *cp, uid_t uid) 
 {
-    LOG(10, ("fsobj::Open: (%s, %d, %d, %d), uid = %d\n",
-	      comp, writep, execp, truncp, uid));
+    LOG(10, ("fsobj::Open: (%s, %d, %d), uid = %d\n",
+	      GetComp(), writep, truncp, uid));
 
     if (cp) {
 	    cp->c_device = 0;
@@ -84,10 +84,8 @@ int fsobj::Open(int writep, int execp, int truncp, venus_cnode *cp, uid_t uid)
     }
     int code = 0;
 
-    if (IsSymLink()) {
-	code = ELOOP;
-	goto Exit;
-    }
+    if (IsSymLink())
+	return ELOOP;
 
     /*  write lock the object if we might diddle it below.  Disabling
      * replacement and bumping reference counts are performed
@@ -111,8 +109,6 @@ int fsobj::Open(int writep, int execp, int truncp, venus_cnode *cp, uid_t uid)
 	    Recov_EndTrans(((EMULATING(this) || LOGGING(this)) ? DMFP : CMFP));
 	}
     }
-    if (execp)
-	Execers++;
 
     /* Do truncate if necessary. */
     if (truncp && writep) {	/* truncp is acted upon only if writep */
@@ -202,8 +198,6 @@ Exit:
 		Recov_EndTrans(0);
 	    }
 	}
-	if (execp)
-	    Execers--;
 	FSO_RELE(this);
 	EnableReplacement();
     }
@@ -215,7 +209,7 @@ Exit:
 /* We CANNOT return ERETRY from this routine! */
 int fsobj::Sync(uid_t uid) 
 {
-    LOG(10, ("fsobj::Sync: (%s), uid = %d\n", comp, uid));
+    LOG(10, ("fsobj::Sync: (%s), uid = %d\n", GetComp(), uid));
 
     int code = 0;
 
@@ -263,7 +257,7 @@ int fsobj::Sync(uid_t uid)
     if (v->type == VPT_Worker)
         ((worker *)v)->StoreFid = NullFid;
     if (code) {
-        eprint("failed to store %s on server", comp);
+        eprint("failed to store %s on server", GetComp());
         switch (code) {
         case ENOSPC: eprint("server partition full"); break;
         case EDQUOT: eprint("over your disk quota"); break;
@@ -279,20 +273,14 @@ int fsobj::Sync(uid_t uid)
 
 /* Call with object write-locked. */
 /* We CANNOT return ERETRY from this routine! */
-void fsobj::Release(int writep, int execp) 
+void fsobj::Release(int writep)
 {
-    LOG(10, ("fsobj::Release: (%s, %d, %d)\n", comp, writep, execp));
+    LOG(10, ("fsobj::Release: (%s, %d)\n", GetComp(), writep));
 
     FSO_ASSERT(this, openers != 0);
 
     openers--;
 
-    if (execp) {
-	if (!EXECUTING(this))
-	    { print(logFile); CHOKE("fsobj::Release: !EXECUTING"); }
-	Execers--;
-    }
-
     if (writep) {
 	PromoteLock();    
 
@@ -326,7 +314,7 @@ void fsobj::Release(int writep, int execp)
     return;
 }
 
-int fsobj::Close(int writep, int execp, uid_t uid) 
+int fsobj::Close(int writep, uid_t uid) 
 {
     int code = 0;
 
@@ -334,7 +322,7 @@ int fsobj::Close(int writep, int execp, uid_t uid)
      * to close. */
     if (writep && Writers == 1)
         code = Sync(uid);
-    Release(writep, execp);
+    Release(writep);
     return code;
 }
 
@@ -344,7 +332,7 @@ int fsobj::Close(int writep, int execp, uid_t uid)
 int fsobj::Access(long rights, int modes, uid_t uid) 
 {
     LOG(10, ("fsobj::Access : (%s, %d, %d), uid = %d\n",
-	      comp, rights, modes, uid));
+	      GetComp(), rights, modes, uid));
 
     int code = 0;
 
@@ -453,9 +441,8 @@ int fsobj::Access(long rights, int modes, uid_t uid)
     /* !!! important point, this is where we map unauthenticated users to
      * System:AnyUser !!! */
     userent *ue = vol->realm->GetUser(uid);
-    int tokensvalid = ue->TokensValid();
+    uid_t CheckVuid = ue->GetUid();
     PutUser(&ue);
-    uid_t CheckVuid = (tokensvalid ? uid : ALL_UIDS);
 
     if ((code = CheckAcRights(CheckVuid, rights, 1)) != ENOENT)
 	return(code);
@@ -482,7 +469,7 @@ int fsobj::Access(long rights, int modes, uid_t uid)
 /* Explicit parameter for TRAVERSE_MTPTS? -JJK */
 int fsobj::Lookup(fsobj **target_fso_addr, VenusFid *inc_fid, char *name, uid_t uid, int flags)
 {
-    LOG(10, ("fsobj::Lookup: (%s/%s), uid = %d\n", comp, name, uid));
+    LOG(10, ("fsobj::Lookup: (%s/%s), uid = %d\n", GetComp(), name, uid));
 
     /* We're screwed if (name == "." or ".."). -JJK */
     CODA_ASSERT(!STREQ(name, ".") && !STREQ(name, ".."));
@@ -535,11 +522,6 @@ int fsobj::Lookup(fsobj **target_fso_addr, VenusFid *inc_fid, char *name, uid_t
 get_object:
 	code = FSDB->Get(&target_fso, &target_fid, uid, status, name);
 
-	if (realm) {
-	    realm->PutRef();
-	    realm = NULL;
-	}
-
 	if (code) {
 	    if (code == EINCONS && inc_fid != 0) *inc_fid = target_fid;
 
@@ -550,7 +532,7 @@ get_object:
 	    if (code == ESYNRESOLVE && vol->IsReplicated())
 		((repvol *)vol)->ResSubmit(&((VprocSelf())->u.u_resblk), &fid);
 
-	    return(code);
+	    goto done;
 	}
 
 	/* Handle mount points. */
@@ -580,7 +562,7 @@ get_object:
 		code = target_fso->TryToCover(inc_fid, uid);
 		if (code == EINCONS || code == ERETRY) {
 		    FSDB->Put(&target_fso);
-		    return(code);
+		    goto done;
 		}
 		code = 0;
 		target_fso->DemoteLock();
@@ -599,8 +581,16 @@ get_object:
 	}
     }
 
+    code = 0;
     *target_fso_addr = target_fso;
-    return(0);
+
+done:
+    if (realm) {
+	realm->PutRef();
+	realm = NULL;
+    }
+
+    return(code);
 }
 
 /* Call with the link contents fetched already. */
@@ -608,7 +598,7 @@ get_object:
 int fsobj::Readlink(char *buf, unsigned long len, int *cc, uid_t uid)
 {
     LOG(10, ("fsobj::Readlink : (%s, %x, %d, %x), uid = %d\n",
-	      comp, buf, len, cc, uid));
+	      GetComp(), buf, len, cc, uid));
 
     if (!HAVEALLDATA(this))
 	{ print(logFile); CHOKE("fsobj::Readlink: called without data"); }
