@@ -378,71 +378,53 @@ void fsobj::DeLocalRootParent(fsobj *RepairRoot, VenusFid *GlobalRootFid, fsobj
     }
 
     /* step 2: de-link root-parent and repair-root */
-    if (MtPt == NULL) {
-	Recov_BeginTrans();
-	RVMLIB_REC_OBJECT(*this);
-	RVMLIB_REC_OBJECT(*RepairRoot);
-	dir_Delete(RepairRoot->comp);
-	dir_Create(RepairRoot->comp, GlobalRootFid);
-	if (shared_parent_count == 0)
-		UnsetLocalObj();
-	DetachChild(RepairRoot);
-	RepairRoot->pfso = NULL;
-	RepairRoot->pfid = NullFid;    
-	Recov_EndTrans(MAXFP);
-    } else {
-	LOG(100, ("fsobj::DeLocalRootParent: Volume Root\n"));
-	Recov_BeginTrans();
-	RVMLIB_REC_OBJECT(*this);
-	RVMLIB_REC_OBJECT(*RepairRoot);
-	dir_Delete(RepairRoot->comp);
-	dir_Create(RepairRoot->comp, &MtPt->fid);
-	if (shared_parent_count == 0)
-		UnsetLocalObj();
-	DetachChild(RepairRoot);
-	RepairRoot->pfso = NULL;
-	RepairRoot->pfid = NullFid;    
-	Recov_EndTrans(MAXFP);
-    }
+    Recov_BeginTrans();
+    RVMLIB_REC_OBJECT(*this);
+    RVMLIB_REC_OBJECT(*RepairRoot);
+    dir_Delete(RepairRoot->comp);
+    if (MtPt)	dir_Create(RepairRoot->comp, &MtPt->fid);
+    else	dir_Create(RepairRoot->comp, GlobalRootFid);
+    if (shared_parent_count == 0)
+	UnsetLocalObj();
+    DetachChild(RepairRoot);
+    RepairRoot->pfso = NULL;
+    RepairRoot->pfid = NullFid;    
+    Recov_EndTrans(MAXFP);
 
     /* step 3: re-link root-parent and global-root(if possible) */
-    if (MtPt != NULL) {
-	/* re-establish the child-parent relation between "this" and MtPt */
-	Recov_BeginTrans();
-	MtPt->pfso = this;
-	MtPt->pfid = this->fid;
-	this->AttachChild(MtPt);
-	Recov_EndTrans(MAXFP);
-    } else {
+    fsobj *GlobalRootObj;
+    if (!MtPt) {
 	/* try to get global-root cached as much as possible */
-	fsobj *GlobalRootObj = NULL;
 	/* first try to FSDB::Get GlobalRootObj(include possible fetching) */
 	vproc *vp = VprocSelf();
-	if (FSDB->Get(&GlobalRootObj, GlobalRootFid, vp->u.u_uid, RC_STATUS) != 0) {
-	    LOG(0, ("fsobj::DeLocalRootParent: FSDB::Get can't get GlobalRootObj\n"));
-	} else {
+	if (FSDB->Get(&GlobalRootObj, GlobalRootFid, vp->u.u_uid, RC_STATUS) == 0) {
 	    /* FSDB::Get puts read-locked target, must unlock it.*/
 	    GlobalRootObj->UnLock(RD);
 	}
+	else
+	    LOG(0, ("fsobj::DeLocalRootParent: FSDB::Get can't get GlobalRootObj\n"));
 	/* no matter what happened to FSDB::Get(), search it from hash-table */
 	GlobalRootObj = FSDB->Find(GlobalRootFid);
-	if (GlobalRootObj) {
-	    if (FID_EQ(&fid, &(GlobalRootObj->pfid)) &&
-		GlobalRootObj->pfso == this) {
-		/* 
-		 * this is the case where the side-effect of FSDB::Get() in
-		 * fetching the GlobalObject calls SetParent() which already
-		 * established the child-parent relation between this and GlobalRootObj.
-		 */
-		LOG(0, ("fsobj::DeLocalRootParent:GlobalRoot already hooked\n"));
-	    } else {
-		/* re-establish child-parent relation between "this" and GlobalRootObj */
-		Recov_BeginTrans();
-		GlobalRootObj->pfso = this;
-		GlobalRootObj->pfid = this->fid;
-		this->AttachChild(GlobalRootObj);
-		Recov_EndTrans(MAXFP);
-	    }
+    } else
+	GlobalRootObj = MtPt;
+
+    if (GlobalRootObj) {
+	if (FID_EQ(&fid, &(GlobalRootObj->pfid)) &&
+	    GlobalRootObj->pfso == this)
+	{
+	    /* 
+	     * this is the case where the side-effect of FSDB::Get() in
+	     * fetching the GlobalObject calls SetParent() which already
+	     * established the child-parent relation between this and GlobalRootObj.
+	     */
+	    LOG(0, ("fsobj::DeLocalRootParent:GlobalRoot already hooked\n"));
+	} else {
+	    /* re-establish child-parent relation between "this" and GlobalRootObj */
+	    Recov_BeginTrans();
+	    GlobalRootObj->pfso = this;
+	    GlobalRootObj->pfid = this->fid;
+	    this->AttachChild(GlobalRootObj);
+	    Recov_EndTrans(MAXFP);
 	}
     }
 }
@@ -559,20 +541,21 @@ void fsobj::LocalToMixed(VenusFid *FakeRootFid, VenusFid *LocalChildFid, char *N
     Recov_EndTrans(MAXFP);
 }
 
-/* must not be called from within a transaction */
+/* MUST be called from within a transaction */
 void fsobj::SetComp(char *name)
 {
-    FSO_ASSERT(this, name != NULL);
-    int len = (int) strlen(name) + 1;
-    Recov_BeginTrans();
-    if (comp != NULL) {
-	    RVMLIB_REC_OBJECT(comp);
-	    rvmlib_rec_free(comp);
-	   }
-    comp = (char *)rvmlib_rec_malloc(len);
-    rvmlib_set_range(comp, len);
-    strcpy(comp, name);
-    Recov_EndTrans(MAXFP);
+    RVMLIB_REC_OBJECT(comp);
+    if (comp) rvmlib_rec_free(comp);
+    if (name && name[0] != '\0')
+	 comp = rvmlib_rec_strdup(name);
+    else comp = rvmlib_rec_strdup("");
+}
+
+const char *fsobj::GetComp(void)
+{
+    if (comp && comp[0] != '\0')
+	 return comp;
+    else return FID_(&fid);
 }
 
 /* must not be called from within a transaction */
@@ -823,19 +806,16 @@ int fsobj::ReplaceLocalFakeFid()
 }
 
 /*
-  BEGIN_HTML
-  <a name="fakeify"><strong> the fakeify process to create
+  LocalKakeify -- the fakeify process to create
   representation for an object detected to be in local/global conflict
-  </strong></a>
-  END_HTML
 */
-/* must not be called from within a transaction */
+/* MUST NOT be called from within a transaction */
 /* this method will be called when the volume is exclusively locked */
 int fsobj::LocalFakeify()
 {
     LOG(100, ("fsobj::LocalFakeify: %s, %s\n", comp, FID_(&fid)));
-    int code = 0;
     fsobj *MtPt = NULL;
+    int code = 0;
 
     /* 
      * step 0. purge kernel and scan FSDB to make sure child-parent
@@ -867,15 +847,15 @@ int fsobj::LocalFakeify()
 	/* Laboriously scan database */
 	struct dllist_head *p;
 	list_for_each(p, vol->fso_list) {
-	    fsobj *pf = list_entry_plusplus(p, fsobj, vol_handle);
+	    pf = list_entry_plusplus(p, fsobj, vol_handle);
 
 	    if (!pf->IsDir() || pf->IsMtPt()) continue;
 	    if (!HAVEALLDATA(pf)) continue;
-	    if (!pf->dir_IsParent(&fid)) continue;
-	    /* Found! */
-	    break;
+
+	    if (pf->dir_IsParent(&fid))
+		break; /* Found! */
 	}
-	if (pf == 0) {
+	if (p == &vol->fso_list) {
 	    LOG(0, ("fsobj::LocalFakeify: %s, %s, parent not found\n",
 		    comp, FID_(&fid)));
 	    return(ENOENT);
@@ -993,7 +973,6 @@ int fsobj::LocalFakeify()
     FakeRoot->stat.Date = Vtime();
     FakeRoot->stat.LinkCount = 2;
     FakeRoot->stat.VnodeType = Directory;
-    FakeRoot->Matriculate();		/* need this ??? -luqi */
     FakeRoot->pfid = pf->fid;
     FakeRoot->pfso = pf;
     /* Create the target directory. */
@@ -1007,6 +986,8 @@ int fsobj::LocalFakeify()
     /* add an new entry to the LRDB maintained fid-map */
     LRDB->RFM_Insert(&FakeRootFid, &GlobalRootFid, &fid, &pf->fid,
 		     &GlobalChildFid, &LocalChildFid, comp, MtPt);
+
+    FakeRoot->Matriculate();		/* need this ??? -luqi */
     Recov_EndTrans(MAXFP);
 
     FSDB->Put(&FakeRoot);
