@@ -62,6 +62,10 @@ extern "C" {
 
 #include <mkpath.h>
 
+#ifndef INADDR_LOOPBACK
+#define INADDR_LOOPBACK 0x7f000001
+#endif
+
 /* from venus */
 #include "fso.h"
 #include "venus.private.h"
@@ -147,7 +151,7 @@ Next:
         /* Bind to it. */
         struct sockaddr_in sin;
         sin.sin_family = AF_INET;
-        sin.sin_addr.s_addr = INADDR_ANY;
+        sin.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
         sin.sin_port = marinerport;
         if (bind(sock, (struct sockaddr *)&sin, (socklen_t) sizeof(sin)) < 0) {
             eprint("MarinerInit: bind failed (%d)", errno);
@@ -244,15 +248,16 @@ void MarinerMux(fd_set *mask)
 
 void MarinerLog(const char *fmt, ...) {
     va_list ap;
-    char buf[180];
+    char buf[CODA_MAXNAMLEN+1];
     int len;
     mariner_iterator next;
     mariner *m;
 
     va_start(ap, fmt);
-    vsnprintf(buf, 180, fmt, ap);
+    vsnprintf(buf, CODA_MAXNAMLEN, fmt, ap);
     va_end(ap);
 
+    buf[CODA_MAXNAMLEN] = '\0';
     len = (int) strlen(buf);
 
     while ((m = next()))
@@ -269,7 +274,7 @@ void MarinerReport(VenusFid *fid, uid_t uid) {
     mariner_iterator next;
     mariner *m;
     while ((m = next()))
-	if (m->reporting && (m->uid == ALL_UIDS || m->uid == uid)) {
+	if (m->reporting && (m->uid == ANYUSER_UID || m->uid == uid)) {
 	    if (first) {
 		m->u.Init();
 		m->u.u_uid = uid;
@@ -324,7 +329,7 @@ mariner::mariner(int afd) :
     dying = 0;
     logging = 0;
     reporting = 0;
-    uid = ALL_UIDS;
+    uid = ANYUSER_UID;
     fd = afd;
     memset(commbuf, 0, MWBUFSIZE);
 
@@ -446,7 +451,7 @@ void mariner::main(void)
 	    Write(
 "Commands are:\n"
 "\thelp, debugon, debugoff, dumpcore, quit, rpc2t\n"
-"\tcop <modes>, umc, set:fetch, clear:fetch, reporton <uid>, reportoff\n"
+"\tcop <modes>, set:fetch, clear:fetch, reporton <uid>, reportoff\n"
 "\t, fd <fd>pathstat <pathname>, fidstat <fid>, rpc2stat, print <args>\n");
 	}
 	else if (STREQ(argv[0], "debugon")) {
@@ -487,10 +492,6 @@ void mariner::main(void)
 	    }
 	    Write("COPModes = %x\n", COPModes);
 	}
-	else if (STREQ(argv[0], "umc")) {
-	    UseMulticast = (1 - UseMulticast);
-	    Write("UseMulticast is now %d.\n", UseMulticast);
-	}
 	else if (STREQ(argv[0], "set:fetch")) {
 	    logging = 1;
 	}
@@ -499,7 +500,7 @@ void mariner::main(void)
 	}
 	else if (STREQ(argv[0], "reporton")) {
 	    reporting = 1;
-	    uid = (argc == 1 ? ALL_UIDS : atoi(argv[1]));
+	    uid = (argc == 1 ? ANYUSER_UID : atoi(argv[1]));
 	}
 	else if (STREQ(argv[0], "reportoff")) {
 	    reporting = 0;
