@@ -47,11 +47,11 @@ extern "C" {
 Realm::Realm(const char *realm_name)
 {
     RVMLIB_REC_OBJECT(name);
-    name = rvmlib_strdup(realm_name);
+    name = rvmlib_rec_strdup(realm_name);
     CODA_ASSERT(name);
 
     RVMLIB_REC_OBJECT(rootvolname);
-    rootvolname = rvmlib_strdup(DEFAULT_ROOTVOLNAME);
+    rootvolname = rvmlib_rec_strdup(DEFAULT_ROOTVOLNAME);
     CODA_ASSERT(rootvolname);
 
     rec_list_head_init(&realms);
@@ -102,7 +102,7 @@ void Realm::ResetTransient(void)
 {
     rootservers = NULL;
     refcount = 0;
-    system_anyuser = new userent(Id(), (uid_t)-1);
+    system_anyuser = new userent(Id(), ANYUSER_UID);
 
     if (rvmlib_in_transaction() && !rec_refcount)
 	delete this;
@@ -121,11 +121,16 @@ void Realm::Rec_PutRef(void)
 /* MAY be called from within a transaction */
 void Realm::PutRef(void)
 {
-    int intrans;
-
     CODA_ASSERT(refcount);
     refcount--;
 
+    return;
+
+/* The following code is too agressive at the moment. We end up killing a newly
+ * created realm mount between the lookup and the getattr. -JH */
+#if 0
+    int intrans;
+
     if (refcount || rec_refcount)
 	return;
 
@@ -137,6 +142,7 @@ void Realm::PutRef(void)
 
     if (!intrans)
 	Recov_EndTrans(MAXFP);
+#endif
 }
 
 /* Get a connection to any server (as root). */
@@ -230,7 +236,7 @@ void Realm::SetRootVolName(char *name)
     Recov_BeginTrans();
     RVMLIB_REC_OBJECT(rootvolname);
     rvmlib_rec_free(rootvolname);
-    rootvolname = rvmlib_strdup(name);
+    rootvolname = rvmlib_rec_strdup(name);
     CODA_ASSERT(rootvolname);
     Recov_EndTrans(MAXFP);
 }
