@@ -201,7 +201,7 @@ int ConsoleUser(uid_t user)
 #define	UTMP_FILE   "/etc/utmp"
 #endif
 
-    uid_t uid = ALL_UIDS;
+    uid_t uid = ANYUSER_UID;
 
     FILE *fp = fopen(UTMP_FILE, "r");
     if (fp == NULL) return(uid);
@@ -248,6 +248,9 @@ userent::~userent() {
 long userent::SetTokens(SecretToken *asecret, ClearToken *aclear) {
     LOG(100, ("userent::SetTokens: uid = %d\n", uid));
 
+    if (uid == (uid_t)-1)
+	return EPERM;
+
     if (uid == V_UID) {
 	eprint("root acquiring Coda tokens!");
     }
@@ -366,8 +369,10 @@ LOG(100, ("After HDB::ResetUser in userent::Reset\n"));
 	connent *c = 0;
 	connent *tc = 0;
 	for (c = next(); c != 0; c = tc) {
-	    tc = next();		/* read ahead */
+	    tc = next(); /* read ahead */
+	    if (tc) tc->GetRef(); /* make sure we don't lose the next connent */
 	    (void)c->Suicide(1);
+	    if (tc) tc->PutRef();
 	}
     }
 
