@@ -20,6 +20,10 @@ listed in the file CREDITS.
 extern "C" {
 #endif
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <sys/file.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -30,7 +34,6 @@ extern "C" {
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <fcntl.h>
 #include <netdb.h>
 #ifdef __cplusplus
 }
@@ -50,7 +53,6 @@ extern "C" {
 #include "sighand.h"
 #include "user.h"
 #include "venus.private.h"
-#include "venus.version.h"
 #include "venuscb.h"
 #include "venuswb.h"
 #include "venusrecov.h"
@@ -60,6 +62,7 @@ extern "C" {
 #include "coda_assert.h"
 #include "codaconf.h"
 #include "realmdb.h"
+#include "daemonizer.h"
 
 #include "nt_util.h"
 #ifdef __CYGWIN32__
@@ -75,7 +78,7 @@ uid_t V_UID;
 /* *****  Exported variables  ***** */
 /* globals in the .bss are implicitly initialized to 0 according to ANSI-C standards */
 vproc *Main;
-VenusFid	rootfid;
+VenusFid rootfid;
 long rootnodeid;
 int CleanShutDown;
 int SearchForNOreFind;  // Look for better detection method for iterrupted hoard walks. mre 1/18/93
@@ -98,7 +101,7 @@ int masquerade_port;
 int PiggyValidations;
 
 
-#ifdef HAVE_SYS_UN_H
+#if defined(HAVE_SYS_UN_H) && !defined(__CYGWIN32__)
 int mariner_tcp_enable = 0;
 #else
 int mariner_tcp_enable = 1;
@@ -123,6 +126,9 @@ struct in_addr venus_relay_addr = { INADDR_LOOPBACK };
 
 /* *****  venus.c  ***** */
 
+/* socket connecting us back to our parent */
+int parent = -1;
+
 /* local-repair modification */
 int main(int argc, char **argv)
 {
@@ -132,11 +138,13 @@ int main(int argc, char **argv)
     ParseCmdline(argc, argv);
     DefaultCmdlineParms();   /* read /etc/coda/venus.conf */
 
+    if (LogLevel == 0)
+	parent = daemonize(VenusPidFile);
+
     /* open the console file and print vital info */
     freopen(consoleFile, "a+", stderr);
-    eprint("Coda Venus, version %d.%d.%d\n",
-	   VenusMajorVersion, VenusMinorVersion, VenusReleaseVersion);
-    
+    eprint("Coda Venus, version " PACKAGE_VERSION);
+
     CdToCacheDir(); 
     CheckInitFile();
     SetRlimits();
@@ -175,6 +183,7 @@ int main(int argc, char **argv)
     DaemonInit();   /* before any Daemons initialize and after LogInit */
     StatsInit();
     SigInit();      /* set up signal handlers */
+
     DIR_Init(RvmType == VM ? DIR_DATA_IN_VM : DIR_DATA_IN_RVM);
     RecovInit();    /* set up RVM and recov daemon */
     CommInit();     /* set up RPC2, {connection,server,mgroup} lists, probe daemon */
@@ -190,7 +199,6 @@ int main(int argc, char **argv)
     WritebackInit(); /* set up writeback subsystem */
     AdviceInit();   /* set up AdSrv and start the advice daemon */
     LRInit();	    /* set up local-repair database */
-    //    VFSMount();
 
     /* Get the Root Volume. */
     eprint("Mounting root volume...");
@@ -203,6 +211,8 @@ int main(int argc, char **argv)
     UnsetInitFile();
     eprint("Venus starting...");
 
+    freopen("/dev/null", "w", stdout);
+
     /* Act as message-multiplexor/daemon-dispatcher. */
     for (;;) {
 	/* Wait for a message or daemon expiry. */
@@ -243,6 +253,8 @@ int main(int argc, char **argv)
     fflush(logFile);
     fflush(stderr);
 
+    MarinerLog("shutdown in progress");
+
     LWP_TerminateProcessSupport();
 
 #if defined(__CYGWIN32__)
@@ -284,20 +296,8 @@ static void ParseCmdline(int argc, char **argv) {
 		i++, CacheDir = argv[i];
 	    else if (STREQ(argv[i], "-m"))
 		i++, COPModes = atoi(argv[i]);
-	    else if (STREQ(argv[i], "-mc"))
-		i++, UseMulticast = atoi(argv[i]);
 	    else if (STREQ(argv[i], "-maxworkers"))  /* number of worker threads */
 		i++, MaxWorkers = atoi(argv[i]);
-	    else if (STREQ(argv[i], "-maxworktime")) {  /* max acceptible pause times */
-		extern struct timeval cont_sw_threshold;
-		cont_sw_threshold.tv_sec = (atoi(argv[++i]));
-		cont_sw_threshold.tv_usec = 0;
-	    }
-            else if (STREQ(argv[i], "-maxrunwait")) {  /* max acceptible lwp run-wait time */
-                extern struct timeval run_wait_threshold;
-                run_wait_threshold.tv_sec = (atoi(argv[++i]));
-                run_wait_threshold.tv_usec = 0;
-            }
 	    else if (STREQ(argv[i], "-weakthresh")) {   /* Threshold at which to go to weak mode */
 		WCThresh = atoi(argv[++i]);		/* in Bytes/sec */
 	    }
@@ -429,6 +429,9 @@ static void DefaultCmdlineParms()
     CODACONF_STR(VenusLogDevice,    "rvm_log",        "/usr/coda/LOG");
     CODACONF_STR(VenusDataDevice,   "rvm_data",       "/usr/coda/DATA");
 
+    CODACONF_INT(rpc2_timeout,	    "RPC2_timeout",   DFLT_TO);
+    CODACONF_INT(rpc2_retries,	    "RPC2_retries",   DFLT_RT);
+
     CODACONF_INT(T1Interval,	    "serverprobe",    150);
     // used to be 12 minutes
 
@@ -460,7 +463,7 @@ static void DefaultCmdlineParms()
 
     CODACONF_INT(MLEs, "cml_entries", 0);
     {
-	if (!MLEs) MLEs = CacheBlocks / BLOCKS_PER_MLE;
+	if (!MLEs) MLEs = CacheFiles * MLES_PER_FILE;
 
 	if (MLEs < MIN_MLE) {
 	    eprint("Cannot start: minimum number of cml entries is %d",MIN_MLE);
@@ -470,7 +473,7 @@ static void DefaultCmdlineParms()
 
     CODACONF_INT(HDBEs, "hoard_entries", 0);
     {
-	if (!HDBEs) HDBEs = CacheBlocks / BLOCKS_PER_HDBE;
+	if (!HDBEs) HDBEs = CacheFiles / FILES_PER_HDBE;
 
 	if (HDBEs < MIN_HDBE) {
 	    eprint("Cannot start: minimum number of hoard entries is %d",
