@@ -76,10 +76,7 @@ extern "C" {
 #define EASRSTARTED     200
 
 
-/*  *****  Command-line/vstab parameter defaults.  ***** */
-
-#define	VSTAB	"/usr/coda/etc/vstab"
-
+/*  *****  parameter defaults.  ***** */
 #if defined(DJGPP)
 #define DFLT_VR "N:"                     /* Venus Root */ 
 #define MCFD    16                       /* Michael Callahan File Descriptor? */
@@ -93,9 +90,18 @@ extern "C" {
 #define	DFLT_CD	"/usr/coda/venus.cache"	    /* cache directory */
 #endif
 
-const int MIN_CB = 2048;
-#define UNSET_PRIMARYUSER 0		    /* primary user of this machine */
+/* rule of thumb */
+const int BLOCKS_PER_FILE = 24;
+const int MLES_PER_FILE = 4;
+const int FILES_PER_HDBE = 2;
 
+const int MIN_CB = 2048;
+const int MIN_CF = MIN_CB / BLOCKS_PER_FILE;
+const int MIN_MLE = MIN_CF * MLES_PER_FILE;
+const int MIN_HDBE = MIN_CF / FILES_PER_HDBE;
+
+
+#define UNSET_PRIMARYUSER 0		    /* primary user of this machine */
 const int FREE_FACTOR = 16;
 
 
@@ -118,7 +124,7 @@ const gid_t V_GID = 513;    /* GID that the venus process runs under. */
 #else
 const gid_t V_GID = 65534;    /* GID that the venus process runs under. */
 #endif
-const uid_t ALL_UIDS = (uid_t)-1;
+const uid_t ANYUSER_UID = (uid_t)-1;
 const uid_t HOARD_UID = (uid_t)-2; /* uid of hoard daemon */
 const uid_t UNSET_UID = (uid_t)-666; /* beastly but recognizable */
 const unsigned short V_MODE = 0600;
@@ -284,9 +290,9 @@ void rds_printer(char * ...);
 void VenusPrint(int, char **);
 void VenusPrint(FILE *, int, char **);
 void VenusPrint(int, int, char **);
-char *VenusOpStr(int);
-char *IoctlOpStr(int);
-char *VenusRetStr(int);
+const char *VenusOpStr(int);
+const char *IoctlOpStr(unsigned char nr);
+const char *VenusRetStr(int);
 void VVPrint(FILE *, vv_t **);
 int binaryfloor(int);
 void LogInit();
@@ -329,6 +335,7 @@ extern struct timeval DaemonExpiry;
 class vproc;
 extern vproc *Main;
 extern VenusFid rootfid;
+extern int parent;
 extern long rootnodeid;
 extern int CleanShutDown;
 extern char *venusRoot;
