@@ -63,7 +63,6 @@ static const int VolCheckPointInterval = 10 * 60;
 static	const int UserRPMInterval = 15 * 60;  
 static const int LocalSubtreeCheckInterval = 10 * 60;
 static const int VolTrickleReintegrateInterval = 10;
-static const int AutoWBPermitRequestInterval = 30;
 
 char voldaemon_sync;
 
@@ -89,7 +88,6 @@ void VolDaemon(void)
     time_t LastRPM = curr_time;
     time_t LastLocalSubtree = curr_time;
     time_t LastTrickleReintegrate = curr_time;
-    time_t LastWBPermitRequest = curr_time;
 
     for (;;) {
 	VprocWait(&voldaemon_sync);
@@ -142,12 +140,6 @@ void VolDaemon(void)
 		
 		VDB->CheckLocalSubtree();
 	    }
-	    
-	    /* Ask for a writeback permit if I don't have one */
-	    if (curr_time - LastWBPermitRequest >= AutoWBPermitRequestInterval) {
-		LastWBPermitRequest = curr_time;
-		VDB->AutoRequestWBPermit();
-	    }
 	}
 
 	END_TIMING();
@@ -291,18 +283,6 @@ void vdb::CheckLocalSubtree()
         v->CheckLocalSubtree();
 }
 
-void vdb::AutoRequestWBPermit()
-{
-    repvol_iterator next;
-    repvol *v;
-    vproc *vp = VprocSelf();
-    /* XXX SSS replace this with something useful */
-
-    while ((v = next()))
-	if (v->flags.autowriteback && !v->flags.writebacking)
-	    v->EnterWriteback(vp->u.u_uid);
-}
-
 
 /* Note: no longer in class vdb, since VolDaemon isn't (Satya, 5/20/95) */
 void TrickleReintegrate()
