@@ -178,10 +178,6 @@ void vproc::open(struct venus_cnode *cp, int flags) {
     int truncp = (flags & C_O_TRUNC) != 0;
     int exclp =  (flags & C_O_EXCL)  != 0;
     int createp =  (flags & C_O_CREAT)  != 0;
-    int	execp =	0;	    /* With VFS we're no longer told of execs! -JJK */
-
-    if ( createp ) 
-	    writep = 1;
 
     fsobj *f = 0;
 
@@ -223,7 +219,7 @@ void vproc::open(struct venus_cnode *cp, int flags) {
 	}
 
 	/* Do the operation. */
-	u.u_error = f->Open(writep, execp, truncp, cp, u.u_uid);
+	u.u_error = f->Open(writep, truncp, cp, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
 FreeLocks:
@@ -247,7 +243,6 @@ void vproc::close(struct venus_cnode *cp, int flags)
 
     /* Expand the flags argument into some useful predicates. */
     int writep = (flags & (C_O_WRITE | C_O_TRUNC)) != 0;
-    int	execp =	0;	    /* ??? -JJK */
     //int not_written = 0; /* flags & C_O_NO_WRITES; */
 
     fsobj *f = 0;
@@ -271,7 +266,7 @@ void vproc::close(struct venus_cnode *cp, int flags)
           LOG(0, ("vproc::close: Don't have DATA and not DYING! (fid = %s, flags = %x)\n", FID_(&cp->c_fid), flags));
 
 	/* Do the operation. */
-	u.u_error = f->Close(writep, execp, u.u_uid /*, not_written */);
+	u.u_error = f->Close(writep, u.u_uid /*, not_written */);
 
 FreeLocks:
 	FSDB->Put(&f);
@@ -287,13 +282,13 @@ FreeLocks:
 }
 
 
-void vproc::ioctl(struct venus_cnode *cp, unsigned int com,
+void vproc::ioctl(struct venus_cnode *cp, unsigned char nr,
 		   struct ViceIoctl *data, int flags) 
 {
     LOG(1, ("vproc::ioctl(%d): fid = %s, com = %s\n",
-	     u.u_uid, FID_(&cp->c_fid), IoctlOpStr(com)));
+	     u.u_uid, FID_(&cp->c_fid), IoctlOpStr(nr)));
 
-    do_ioctl(&cp->c_fid, com, data);
+    do_ioctl(&cp->c_fid, nr, data);
 
     if (u.u_error == EINCONS) {
 	u.u_error = ENOENT;
