@@ -318,7 +318,8 @@ void VFSMount()
 	    ent = getmntent(fd);
 	    if (!ent) break;
 
-	    if (STREQ(ent->mnt_fsname, "Coda") &&
+	    if ((STREQ(ent->mnt_fsname, "Coda") ||
+		 STREQ(ent->mnt_fsname, "coda")) &&
 		STREQ(ent->mnt_dir, venusRoot)) {
 		mounted = 1;
 		break;
@@ -328,8 +329,10 @@ void VFSMount()
 
 	if (mounted) {
 	    eprint("%s already mounted", venusRoot);
-	    if (allow_reattach)
+	    if (allow_reattach) {
+		kill(getpid(), SIGUSR1);
 		return;
+	    }
 	    exit(-1);
 	}
     }
@@ -393,7 +396,8 @@ void VFSMount()
 	    eprint("CHILD: mount system call failed. Killing parent.\n");
 	    kill(parent, SIGKILL);
 	} else {
-	    eprint("%s now mounted.\n", venusRoot);
+	    eprint("%s now mounted.", venusRoot);
+	    kill(parent, SIGUSR1);
 	}
 
 child_done:
@@ -402,7 +406,10 @@ child_done:
     }
 
     /* we just wait around to reap the first child */
-    while (waitpid(child, NULL, 0) != child) /* loop */;
+    pid_t pid;
+    do {
+	pid = waitpid(child, NULL, 0);
+    } while (pid == -1 && errno == EINTR);
 #endif /* __BSD44__ || __linux__ */
 
 #ifdef sun
@@ -850,7 +857,7 @@ int IsAPrefetch(msgent *m) {
     if (in->ih.opcode != CODA_IOCTL)
 	return(0);
 
-    return (in->coda_ioctl.cmd == VIOCPREFETCH);
+    return (_IOC_NR(in->coda_ioctl.cmd) == _VIOCPREFETCH);
 }
 
 void DispatchWorker(msgent *m) {
@@ -1040,8 +1047,8 @@ void worker::AwaitRequest() {
 /* Called by workers after completing a service request. */
 void worker::Resign(msgent *msg, int size) {
     if (returned) {
-	char *opstr = VenusOpStr((int) ((union outputArgs*)msg->msg_buf)->oh.opcode);
-	char *retstr = VenusRetStr((int) ((union outputArgs *)msg->msg_buf)->oh.result);
+	const char *opstr = VenusOpStr((int) ((union outputArgs*)msg->msg_buf)->oh.opcode);
+	const char *retstr = VenusRetStr((int) ((union outputArgs *)msg->msg_buf)->oh.result);
 	
 #ifdef TIMING
 	float elapsed;
@@ -1074,8 +1081,8 @@ void worker::Return(msgent *msg, size_t size) {
     if (returned)
 	CHOKE("worker::Return: already returned!");
 
-    char *opstr = VenusOpStr((int) ((union outputArgs*)msg->msg_buf)->oh.opcode);
-    char *retstr = VenusRetStr((int) ((union outputArgs*)msg->msg_buf)->oh.result);
+    const char *opstr = VenusOpStr((int) ((union outputArgs*)msg->msg_buf)->oh.opcode);
+    const char *retstr = VenusRetStr((int) ((union outputArgs*)msg->msg_buf)->oh.result);
 
 #ifdef	TIMING
     float elapsed;
@@ -1211,6 +1218,8 @@ void worker::main(void)
 		char outbuf[VC_MAXDATASIZE];
 		struct ViceIoctl data;
                 int cmd = in->coda_ioctl.cmd;
+		unsigned char type = _IOC_TYPE(cmd);
+		unsigned char nr = _IOC_NR(cmd);
 
 		data.in = (char *)in + (int)in->coda_ioctl.data;
 		data.in_size = 0;
@@ -1219,7 +1228,14 @@ void worker::main(void)
 
 		LOG(100, ("CODA_IOCTL: u.u_pid = %d u.u_pgid = %d\n", u.u_pid, u.u_pgid));
 
-		if (cmd == VIOC_UNLOADKERNEL){
+		if (type != 'V') {
+		    u.u_error = EOPNOTSUPP;
+                    out->coda_ioctl.len = 0;		
+		    size = sizeof(struct coda_ioctl_out);
+		    break;
+		}
+
+		if (nr == _VIOC_UNLOADKERNEL) {
                     out->oh.result = 0;
                     out->coda_ioctl.len = 0;		
                     /* we have to Resign here because we will exit before
@@ -1236,17 +1252,18 @@ void worker::main(void)
                     exit(0);	
 		}
 			
-		if (cmd == VIOCPREFETCH)
+		if (nr == _VIOCPREFETCH)
 		    worker::nprefetchers++;
 
 		MAKE_CNODE(vtarget, in->coda_ioctl.Fid, 0);
 		data.in_size = in->coda_ioctl.len;
-		ioctl(&vtarget, cmd, &data, in->coda_ioctl.rwflag);
+
+		ioctl(&vtarget, nr, &data, in->coda_ioctl.rwflag);
 
 		out->coda_ioctl.len = data.out_size;
 		out->coda_ioctl.data = (char *)(sizeof (struct coda_ioctl_out));
 		memcpy((char *)out + (int)out->coda_ioctl.data, data.out, data.out_size);
-		if (cmd == VIOCPREFETCH)
+		if (nr == _VIOCPREFETCH)
 		    worker::nprefetchers--;
 
 		size = sizeof (struct coda_ioctl_out) + data.out_size;
