@@ -79,7 +79,6 @@ extern "C" {
 #include <rescomm.h>
 #include <ops.h>
 #include <timing.h>
-#include <writeback.h>
 
 #define	EMPTYDIRBLOCKS	    2
 
@@ -2533,10 +2532,9 @@ long FS_ViceValidateVols(RPC2_Handle cid, RPC2_Integer numVids,
     VFlagBS->SeqLen = 0;
     memset(VFlagBS->SeqBody, 0, VFlagBS->MaxSeqLen);
 
-    if ( numVids > VFlagBS->MaxSeqLen ) {
-	    SLog(0, "Client sending wrong output buffer while validating"
-		 "volumes:MaxSeqLen %d, should be %d", 
-		 VFlagBS->MaxSeqLen, numVids);
+    if (VFlagBS->MaxSeqLen < numVids) {
+	    SLog(0, "Wrong output buffer while validating volumes: "
+		 "MaxSeqLen %d, should be %d", VFlagBS->MaxSeqLen, numVids);
 	    return(EINVAL);
     }
 
@@ -2578,6 +2576,11 @@ long FS_ViceValidateVols(RPC2_Handle cid, RPC2_Integer numVids,
 
 	/* check the version stamp in our slot in the vector */
 	index = i * count + ix;
+	if (VSBS->SeqLen < ((index+1) * sizeof(RPC2_Unsigned))) {
+	    SLog(9, "ValidateVolumes: short input");
+	    goto InvalidVolume;
+	}
+
 	if ((long)ntohl(((RPC2_Unsigned *) VSBS->SeqBody)[index]) == myVS) {
 	    SLog(8, "ValidateVolumes: 0x%x ok, adding callback", 
 		   Vids[i].Vid);
