@@ -57,6 +57,7 @@ extern "C" {
 #include <sys/time.h>
 #include <sys/resource.h>
 #include <sys/file.h>
+#include <time.h>
 #include "coda_string.h"
 #include <errno.h>
 #include <signal.h>
@@ -114,6 +115,7 @@ extern int Fcon_Init();
 #include <rescomm.h>
 #include <lockqueue.h>
 #include "coppend.h"
+#include "daemonizer.h"
 
 
 /* *****  Exported variables  ***** */
@@ -178,8 +180,8 @@ static char *srvhost;		// default NULL
 static int trace = 0;		// default 0 
 static int SrvWindowSize = 0;	// default 32
 static int SrvSendAhead = 0;	// default 8
-static int timeout = 0;		// default 15, formerly 30, then 60
-static int retrycnt = 0;	// default 4, formerly 20, then 6
+static int timeout = 0;		// default 60, formerly 15, 30, then 60
+static int retrycnt = 0;	// default 5, formerly 4, 20, then 6
 static int debuglevel = 0;	// Command line set only.
 static int lwps = 0;		// default 6
 static int buffs = 0;		// default 100, formerly 200
@@ -245,7 +247,7 @@ static void ShutDown();
 static int ReadConfigFile(void);
 static int ParseArgs(int, char **);
 static void InitServerKeys(char *, char *);
-static void DaemonizeSrv(void);
+static int DaemonizeSrv(char *pidfile);
 static void InitializeServerRVM(char *name);
 
 #ifdef RVMTESTING
@@ -325,13 +327,14 @@ int main(int argc, char *argv[])
 {
     char    sname[20];
     int     i;
-    FILE   *file;
     struct stat buff;
     PROCESS parentPid, serverPid, resPid, smonPid, resworkerPid;
     RPC2_PortIdent port1, *portlist[1];
     RPC2_SubsysIdent server;
     SFTP_Initializer sei;
     ProgramType *pt;
+    int parent = -1;
+    char *pidfile;
 
     coda_assert_action = CODA_ASSERT_EXIT;
 
@@ -347,13 +350,16 @@ int main(int argc, char *argv[])
 	SLog(0, " [-nocmp] [-nopy] [-dumpvm] [-nosalvageonshutdown] [-mondhost hostname] [-mondport portnumber]");
 	SLog(0, "[-nodebarrenize] [-dir workdir] [-srvhost host]");
 	SLog(0, " [-rvmopt] [-usenscclock]");
-	SLog(0, " [-nowriteback] [-mapprivate] [-zombify]");
+	SLog(0, " [-mapprivate] [-zombify]");
 
 	exit(-1);
     }
 
     (void)ReadConfigFile();
 
+    pidfile = vice_file("srv/pid");
+    parent = DaemonizeSrv(pidfile);
+
     if(chdir(vice_file("srv"))) {
 	SLog(0, "could not cd to %s - exiting", vice_file("srv"));
 	exit(-1);
@@ -362,7 +368,6 @@ int main(int argc, char *argv[])
     unlink("NEWSRV");
 
     SwapLog();
-    DaemonizeSrv();
 
     /* CamHistoInit(); */	
     /* Initialize CamHisto package */
@@ -478,10 +483,6 @@ int main(int argc, char *argv[])
 
     FileMsg();
 
-
-    CODA_ASSERT(file = fopen("pid","w"));
-    fprintf(file,"%d",(int)getpid());
-    fclose(file);
     /* Init per LWP process functions */
     for(i=0;i<MAXLWP;i++)
 	LastOp[i] = StackAllocated[i] = StackUsed[i] = 0;
@@ -585,6 +586,9 @@ int main(int argc, char *argv[])
     TM_GetTimeOfDay(&tp, &tsp);
     SLog(0,"File Server started %s", ctime((const time_t *)&tp.tv_sec));
     StartTime = (unsigned int)tp.tv_sec;
+
+    gogogo(parent);
+
     CODA_ASSERT(LWP_WaitProcess((char *)&parentPid) == LWP_SUCCESS);
     exit(0);
 }
@@ -621,89 +625,89 @@ static void ServerLWP(int *Ident)
     while (1) {
 	LastOp[lwpid] = 0;
 	CurrentClient[lwpid] = (ClientEntry *)0;
-	if ((rc = RPC2_GetRequest(&myfilter, &mycid, &myrequest, 0, GetKeysFromToken, RPC2_XOR, NULL))
-		== RPC2_SUCCESS) {
-	    if (RPC2_GetPrivatePointer(mycid, (char **)&client) != RPC2_SUCCESS) 
-		client = 0;
-	    
-	    if (client) {
-		/* check rpc2 connection handle */
-		if (client->RPCid != mycid) {
-		    SLog(0, "Invalid client pointer from GetPrivatePointer");
-		    myrequest->Header.Opcode = BADCLIENT; /* ignore request & Unbind */
-		    client = 0;
-		}
-		/* check token expiry, compare the token expiry time to the
-		 * receive timestamp in the PacketBuffer. */
-		if (client->SecurityLevel != RPC2_OPENKIMONO &&
-		    myrequest->Prefix.RecvStamp.tv_sec > client->Token.EndTimestamp) {
-		    SLog(0, "Client Token expired");
-		    /* force a disconnection for this rpc2 connection */
-		    myrequest->Header.Opcode = TokenExpired_OP;
-		}
-	    }
-	    LastOp[lwpid] = myrequest->Header.Opcode;
-	    CurrentClient[lwpid] = client;
-	    if (client) {
-		client->LastCall = client->VenusId->LastCall = (unsigned int)time(0);
-		/* the next time is used to eliminate GetTime calls from active stat */
-		if (myrequest->Header.Opcode != GETTIME)
-		    client->VenusId->ActiveCall = client->LastCall;
-		client->LastOp = (int)myrequest->Header.Opcode;
-     	    }
+	rc = RPC2_GetRequest(&myfilter, &mycid, &myrequest, 0,
+			     GetKeysFromToken, RPC2_XOR, NULL);
 
-	    SLog(5, "Worker %d received request %d on cid %d for %s at %s",
-		    lwpid, myrequest->Header.Opcode, mycid,
-		    client ? client->UserName : "NA",
-		    client ? inet_ntoa(client->VenusId->host) : "NA");
-	    if (myrequest->Header.Opcode > 0 && myrequest->Header.Opcode < FETCHDATA) {
-		Counters[TOTAL]++;
-		Counters[myrequest->Header.Opcode]++;
-		if (!(Counters[TOTAL] & 0xFFF)) {
-		    PrintCounters(stdout);
-		}
-	    }
-
-            /* save fields we need, ExecuteRequest will thrash the buffer */
-            opcode = myrequest->Header.Opcode;
-
-	    rc = srv_ExecuteRequest(mycid, myrequest, 0);
-
-	    if (rc) {
-		SLog(0, "srv.c request %d for %s at %s failed: %s",
-			opcode, client ? client->UserName : "NA",
-			client ? inet_ntoa(client->VenusId->host) : "NA",
-			ViceErrorMsg((int)rc));
-		if(rc <= RPC2_ELIMIT) {
-		    if(client && client->RPCid == mycid && !client->DoUnbind) {
-			ObtainWriteLock(&(client->VenusId->lock));
-			CLIENT_Delete(client);
-			ReleaseWriteLock(&(client->VenusId->lock));
-		    }
-		}
-	    }
-	    if(client) {
-		if(client->DoUnbind) {
-		    SLog(0, "Worker%d: Unbinding RPC connection %d",
-							    lwpid, mycid);
-		    RPC2_Unbind(mycid);
-		    AL_FreeCPS(&(client->CPS));
-		    free((char *)client);
-		    client = 0;
-		}
-		else {
-		    client->LastOp = 0;
-		}
-	    }
-            /* if bad client pointer Unbind the rpc connection */
-	    if (opcode == BADCLIENT) {
-		SLog(0, "Worker%d: Unbinding RPC connection %d (BADCLIENT)",
-					    lwpid, mycid);
-		RPC2_Unbind(mycid);
-	    }
+	if (rc != RPC2_SUCCESS) {
+	    SLog(0,"RPC2_GetRequest failed with %s", ViceErrorMsg((int)rc));
+	    continue;
 	}
-	else {
-	    SLog(0,"RPC2_GetRequest failed with %s",ViceErrorMsg((int)rc));
+
+	if (RPC2_GetPrivatePointer(mycid, (char **)&client) != RPC2_SUCCESS) 
+	    client = 0;
+	    
+	/* check rpc2 connection handle */
+	if (client && client->RPCid != mycid) {
+	    SLog(0, "Invalid client pointer from GetPrivatePointer");
+	    myrequest->Header.Opcode = BADCLIENT; /* ignore request & Unbind */
+	    client = 0;
+	}
+
+	/* check token expiry, compare the token expiry time to the
+	 * receive timestamp in the PacketBuffer. */
+	if (client && client->SecurityLevel != RPC2_OPENKIMONO &&
+	    myrequest->Prefix.RecvStamp.tv_sec > client->EndTimestamp) {
+	    SLog(0, "Client Token expired");
+	    /* force a disconnection for this rpc2 connection */
+	    myrequest->Header.Opcode = TokenExpired_OP;
+	}
+
+	LastOp[lwpid] = myrequest->Header.Opcode;
+	CurrentClient[lwpid] = client;
+
+	if (client) {
+	    client->LastCall = client->VenusId->LastCall = (unsigned int)time(0);
+	    /* the next time is used to eliminate GetTime calls from active stat */
+	    if (myrequest->Header.Opcode != GETTIME)
+		client->VenusId->ActiveCall = client->LastCall;
+	    client->LastOp = (int)myrequest->Header.Opcode;
+	}
+
+	SLog(5, "Worker %d received request %d on cid %d for %s at %s",
+	     lwpid, myrequest->Header.Opcode, mycid,
+	     client ? client->UserName : "NA",
+	     client ? inet_ntoa(client->VenusId->host) : "NA");
+
+	if (myrequest->Header.Opcode > 0 && myrequest->Header.Opcode < FETCHDATA) {
+	    Counters[TOTAL]++;
+	    Counters[myrequest->Header.Opcode]++;
+	    if (!(Counters[TOTAL] & 0xFFF))
+		PrintCounters(stdout);
+	}
+
+	/* save fields we need, ExecuteRequest will thrash the buffer */
+	opcode = myrequest->Header.Opcode;
+
+	rc = srv_ExecuteRequest(mycid, myrequest, 0);
+
+	if (rc) {
+	    SLog(0, "srv.c request %d for %s at %s failed: %s",
+		 opcode, client ? client->UserName : "NA",
+		 client ? inet_ntoa(client->VenusId->host) : "NA",
+		 ViceErrorMsg((int)rc));
+
+	    if(client && rc <= RPC2_ELIMIT)
+		client->DoUnbind = 1;
+	}
+	if(client) {
+	    if(client->DoUnbind) {
+		struct Lock *lock = &client->VenusId->lock;
+
+		SLog(0, "Worker%d: Unbinding RPC connection %d",
+		     lwpid, mycid);
+
+		ObtainWriteLock(lock);
+		client->LastOp = 0;
+		CLIENT_Delete(client);
+		ReleaseWriteLock(lock);
+	    } else
+		client->LastOp = 0;
+	}
+	/* if bad client pointer Unbind the rpc connection */
+	if (opcode == BADCLIENT) {
+	    SLog(0, "Worker%d: Unbinding RPC connection %d (BADCLIENT)",
+		 lwpid, mycid);
+	    RPC2_Unbind(mycid);
 	}
     }
 }
@@ -745,7 +749,6 @@ static void ResLWP(int *Ident){
 	    SLog(0, "RPC2_GetRequest failed with %s", 
 		    ViceErrorMsg((int)rc));
     }
-
 }
 
 static void CallBackCheckLWP()
@@ -849,7 +852,7 @@ static void ShutDown()
 
     VShutdown();
 
-    fd = open("SHUTDOWN",O_CREAT+O_RDWR, 0666);
+    fd = open("SHUTDOWN",O_CREAT|O_WRONLY, 0666);
     close(fd);
     exit(0);
 }
@@ -1216,7 +1219,7 @@ void SwapLog()
     
     /* Print out time/date, since date info has "scrolled off" */
     TM_GetTimeOfDay(&tp, 0);
-    SLog(0, "New SrvLog started at %s", ctime((const time_t *)&tp.tv_sec));
+    SLog(0, "Coda Vice, version " PACKAGE_VERSION "\tlog started at %s", ctime(&tp.tv_sec));
 }
 
 static void FileMsg()
@@ -1278,8 +1281,8 @@ static int ReadConfigFile(void)
     CODACONF_INT(trace,		"trace",	0);
     CODACONF_INT(SrvWindowSize,	"windowsize",	32);
     CODACONF_INT(SrvSendAhead,	"sendahead",	8);
-    CODACONF_INT(timeout,	"timeout",	15);
-    CODACONF_INT(retrycnt,	"retrycnt",	4);
+    CODACONF_INT(timeout,	"timeout",	60);
+    CODACONF_INT(retrycnt,	"retrycnt",	5);
     CODACONF_INT(lwps,		"lwps",		6);
     if (lwps > MAXLWP) lwps = MAXLWP;
 
@@ -1342,7 +1345,6 @@ static int ReadConfigFile(void)
     extern int nodebarrenize;
 
     CODACONF_INT(nodebarrenize, "nodebarrenize", 0);
-    CODACONF_INT(NoWritebackConn, "nowriteback", 0);
     CODACONF_INT(zombify, "zombify", 0);
     if (zombify)
         coda_assert_action = CODA_ASSERT_SLEEP;
@@ -1359,8 +1361,6 @@ static int ParseArgs(int argc, char *argv[])
 {
     int   i;
 
-    NoWritebackConn = 0;
-
     for (i = 1; i < argc; i++) {
 	if (!strcmp(argv[i], "-d")) {
 	    debuglevel = atoi(argv[++i]);
@@ -1540,10 +1540,6 @@ static int ParseArgs(int argc, char *argv[])
 		extern int nodebarrenize;
 		nodebarrenize = 1;
 	    }
-	else 
-	    if (!strcmp(argv[i], "-nowriteback")) {
-		NoWritebackConn = 1;
-	    }
 	else 
 	    if (!strcmp(argv[i], "-mapprivate")) {
 		MapPrivate = 1;
@@ -1618,40 +1614,24 @@ void Die(char *msg)
 }
 
 
-static void DaemonizeSrv() { 
-    int  rc; 
+static int DaemonizeSrv(char *pidfile)
+{ 
+    int parent = -1; 
+
+    if (SrvDebugLevel == 0)
+	parent = daemonize(pidfile);
+
    /* Set DATA segment limit to maximum allowable. */
 #ifndef __CYGWIN32__
-    struct rlimit rl;
-    if (getrlimit(RLIMIT_DATA, &rl) < 0) {
-        perror("getrlimit"); exit(-1);
-    }
-    rl.rlim_cur = rl.rlim_max;
-    SLog(0, 
-	   "Resource limit on data size are set to %d\n", rl.rlim_cur);
-    if (setrlimit(RLIMIT_DATA, &rl) < 0) {
-	perror("setrlimit"); exit(-1); 
-    }
-#endif
-    /* the forking code doesn't work well with our "startserver" script. 
-       reactivate this when that silly thing is gone */
-#if 0 
-    child = fork();
-    
-    if ( child < 0 ) { 
-	fprintf(stderr, "Cannot fork: exiting.\n");
-	exit(1);
-    }
-
-    if ( child != 0 ) /* parent */
-	exit(0); 
-#endif 
-
-    rc = setsid();
-#if 0
-    if ( rc < 0 ) {
-	fprintf(stderr, "Error detaching from terminal.\n");
-	exit(1);
+    {
+	struct rlimit rl;
+	if (getrlimit(RLIMIT_DATA, &rl) < 0) {
+	    perror("getrlimit"); exit(-1);
+	}
+	rl.rlim_cur = rl.rlim_max;
+	if (setrlimit(RLIMIT_DATA, &rl) < 0) {
+	    perror("setrlimit"); exit(-1); 
+	}
     }
 #endif
 
@@ -1672,6 +1652,7 @@ static void DaemonizeSrv() {
 #else
     signal(SIGBUS,  (void (*)(int))zombie);
 #endif
+    return parent;
 }
 
 static void InitializeServerRVM(char *name)
