@@ -52,7 +52,8 @@ extern "C" {
 #include "dumpstream.h"
 
 typedef struct entry {
-    long unique, offset;
+    long unique;
+    off_t offset;
     dumpstream *dump;
     struct entry *next;
 } ventry;
@@ -201,7 +202,7 @@ int main(int argc, char **argv)
 
 static void BuildTable(dumpstream *dump, vtable *table)
 {
-    long vnodeNumber;
+    VnodeId vnodeNumber;
     char *buf[SIZEOF_LARGEDISKVNODE];
     VnodeDiskObject *vdo = (VnodeDiskObject *)buf;
 
@@ -209,7 +210,7 @@ static void BuildTable(dumpstream *dump, vtable *table)
     CODA_ASSERT(table->table != NULL);
     memset((void *)table->table, 0, sizeof(ventry*) * table->nslots);
     for (int i = 0; i < table->nvnodes; i++) {
-	long offset;
+	off_t offset;
 	int deleted;
 	if (dump->getNextVnode(vdo, &vnodeNumber, &deleted, &offset) == -1) {
 	    LogMsg(0, VolDebugLevel, stderr, "ERROR -- Failed to get a vnode!");
@@ -242,7 +243,8 @@ static void ModifyTable(dumpstream *dump, VnodeClass vclass, vtable *Table)
 {
     char *buf[SIZEOF_LARGEDISKVNODE];
     VnodeDiskObject *vdo = (VnodeDiskObject *)buf;
-    long nvnodes, nslots, vnodeNumber;
+    long nvnodes, nslots;
+    VnodeId vnodeNumber;
 
     if (dump->getVnodeIndex(vclass, &nvnodes, &nslots) == -1) 
 	exit(-1); /* Already printed out an error */
@@ -262,7 +264,7 @@ static void ModifyTable(dumpstream *dump, VnodeClass vclass, vtable *Table)
     }
 
     int deleted;
-    long offset;
+    off_t offset;
     while (dump->getNextVnode(vdo, &vnodeNumber, &deleted, &offset) != -1) {
 	int vnum = vnodeIdToBitNumber(vnodeNumber);
 	CODA_ASSERT(vnum >= 0);
