@@ -124,7 +124,6 @@ static void peekmem(void);
 static void pokemem(void);
 static void peekxmem(void);
 static void pokexmem(void);
-static void setwb(RPC2_Integer wbflag);
 
 #define ROCKTAG 12345
 struct rockInfo {
@@ -276,10 +275,6 @@ int main(int argc, char **argv)
 	peekxmem();
     else if (strcmp(argv[1], "pokex") == 0)
 	pokexmem();
-    else if (strcmp(argv[1], "enablewb") == 0)
-	setwb(1);
-    else if (strcmp(argv[1], "disablewb") == 0)
-	setwb(0);
     else
     	goto bad_options;
 
@@ -292,7 +287,7 @@ bad_options:
 "\tancient, backup, create, create_rep, clone, dump, dumpestimate,\n"
 "\trestore, info, lock, lookup, makevldb, makevrdb, purge, salvage,\n"
 "\tsetvv, showvnode, shutdown, swaplog, setdebug, updatedb, unlock,\n"
-"\tdumpmem, rvmsize, timing, enablewb, disablewb, printstats,\n"
+"\tdumpmem, rvmsize, timing, printstats,\n"
 "\tshowcallbacks, truncatervmlog,togglemalloc, getmaxvol, setmaxvol,\n"
 "\tpeek, poke, peeks, pokes, peekx, pokex, setlogparms, tracerpc\n"
 "\tgetvolumelist, dumpvrdb\n");
@@ -1157,8 +1152,9 @@ static void info(void)
 static void showvnode(void)
 {
     SE_Descriptor sed;
-    bit32 volumeNumber, vnodeNumber;
-    bit32 unique;
+    VolumeId volumeNumber;
+    VnodeId vnodeNumber;
+    Unique_t unique;
     FILE *outf;
 
     if (these_args < 5) {
@@ -1203,9 +1199,10 @@ static void showvnode(void)
 */
 static void setvv(void) 
 {
-    bit32   volumeNumber, vnodeNumber;
-    bit32   unique;
-    ViceVersionVector	vv;
+    VolumeId volumeNumber;
+    VnodeId vnodeNumber;
+    Unique_t unique;
+    ViceVersionVector vv;
 
     if (these_args != 16){
 	fprintf(stderr, "Usage: volutil setvv volumeNumber vnodeNumber unique <version nubmers(8)> <StoreId (host) (Uniquifier)> <flags>\n");
@@ -1937,30 +1934,6 @@ static void pokexmem(void)
     exit(0);
 }
 
-static void setwb(RPC2_Integer wbflag)
-{
-    long Vid;
-
-    if (these_args != 3) {
-	fprintf(stderr, "Usage: volutil [en,dis]ablewb volumeId\n");
-	exit(-1);
-    }
-
-    if (sscanf(this_argp[2], "%lX", &Vid) != 1){
-	fprintf(stderr, "VolSetWBParms: Bogus volume number %s\n", this_argp[2]);
-	exit(-1);
-    }
-
-    rc = VolSetWBParms(rpcid, Vid, wbflag);
-    if (rc != RPC2_SUCCESS) {
-	fprintf(stderr, "VolSetWBParms failed with %s\n", RPC2_ErrorMsg((int)rc));
-	exit(-1);
-    }
-    printf("WriteBack %sallowed for Volume %lx\n", wbflag ? "" : "dis", Vid);
-
-    exit(0);
-}
-
 static void V_InitRPC(int timeout)
 {
     PROCESS mylpid;
@@ -2029,7 +2002,7 @@ static int V_BindToServer(char *fileserver, char *realm, RPC2_Handle *RPCid)
     else if (realm && U_GetLocalTokens(&ctok, stok, realm) == 0)
     {
 	clientident.SeqLen = sizeof(SecretToken);
-	clientident.SeqBody = (RPC2_ByteSeq)&secret;
+	clientident.SeqBody = (RPC2_ByteSeq)&stok;
 
 	bparms.AuthenticationType = AUTH_METHOD_CODATOKENS;
 	bparms.ClientIdent = &clientident;
