@@ -145,9 +145,6 @@ static void TruncateLog(int, char **, int);
 static void UnloadKernel(int, char **, int);
 static void WaitForever(int, char**, int);
 static void WhereIs(int, char**, int);
-static void WriteBackStart(int, char**, int);
-static void WriteBackStop(int, char**, int);
-static void WriteBackAuto(int, char**, int);
 static void ForceReintegrate(int, char**, int);
 static void WriteDisconnect(int, char**, int);
 static void WriteReconnect(int, char**, int);
@@ -381,22 +378,6 @@ struct command cmdarray[] =
             "Write connect all volumes, or volumes specified",
             NULL
         },
-	{"wbstart", NULL, WriteBackStart,
-	    "cfs wbstart <dir> [<dir> <dir> ...]",
-            "Enable write-back caching on volumes specified",
-            NULL
-        },
-	{"wbstop", NULL, WriteBackStop,
-	    "cfs wbstop <dir> [<dir> <dir> ...]",
-	    "Disable write-back caching on volumes specified",
-	    NULL
-	},
-	{"wbauto", "wb", WriteBackAuto,
-	    "cfs wbauto <dir> [<dir> <dir> ...]",
-	    "Toggle auto write-back cache requesting on volumes specified",
-	    NULL
-	},
-
 	{"forcereintegrate", "fr", ForceReintegrate,
 	    "cfs forcereintegrate <dir> [<dir> <dir> ...]",
 	    "Force modifications in a disconnected volume to the server",
@@ -574,7 +555,7 @@ static void CheckServers(int argc, char *argv[], int opslot)
     }
 
     printf("Contacting servers .....\n"); /* say something so Puneet knows something is going on */
-    rc = pioctl(mountpoint, VIOCCKSERV, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOCCKSERV), &vio, 1);
     if (rc < 0) { PERROR("VIOCCKSERV"); exit(-1); }
 
     /* See if there are any dead servers */
@@ -626,7 +607,7 @@ static void CheckPointML(int argc, char* argv[], int opslot)
     vio.in = ckpdir;
     vio.out_size = 0;
     vio.out = 0;
-    rc = pioctl(codadir, VIOC_CHECKPOINTML, &vio, 1);
+    rc = pioctl(codadir, _VICEIOCTL(_VIOC_CHECKPOINTML), &vio, 1);
     if (rc < 0) { PERROR("VIOC_CHECKPOINTML"); exit(-1); }
     }
 
@@ -656,7 +637,7 @@ static int dirincoda(char *path)
     vio.in_size = 0;
     vio.out = piobuf;
     vio.out_size = CFS_PIOBUFSIZE;
-    rc = pioctl(buf, VIOC_GETFID, &vio, 0);
+    rc = pioctl(buf, _VICEIOCTL(_VIOC_GETFID), &vio, 0);
     return(rc == 0);
     }
 
@@ -675,7 +656,7 @@ static void CheckVolumes(int argc, char *argv[], int opslot)
     vio.in_size = 0;
     vio.out = 0;
     vio.out_size = 0;
-    rc = pioctl(mountpoint, VIOCCKBACK, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOCCKBACK), &vio, 1);
     if (rc < 0) { PERROR("VIOC_VIOCCKBACK"); exit(-1); }
     }
 
@@ -693,11 +674,11 @@ static void ClearPriorities(int argc, char *argv[], int opslot)
     vio.in_size = 0;
     vio.out = 0;
     vio.out_size = 0;
-    rc = pioctl(mountpoint, VIOC_CLEARPRIORITIES, &vio, 0);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_CLEARPRIORITIES), &vio, 0);
     if (rc < 0) { PERROR("  VIOC_CLEARPRIORITIES"); exit(-1); }
 }
 
-#ifndef NDEBUG
+#ifdef UNUSED
 static void Compress(int argc, char *argv[], int opslot)
 {
     int i, rc; 
@@ -714,7 +695,7 @@ static void Compress(int argc, char *argv[], int opslot)
         vio.in_size = 0;
         vio.out = 0;
         vio.out_size = 0;
-        rc = pioctl(argv[i], VIOC_COMPRESS, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOC_COMPRESS), &vio, 1);
         if (rc < 0) { PERROR("VIOC_COMPRESS"); continue; }
         if (argc > 3) printf("\n");
     }
@@ -742,7 +723,7 @@ static void Redir (int argc, char *argv[], int opslot)
     vio.out = NULL;
 
     /* Do the pioctl */
-    rc = pioctl(argv[2], VIOC_REDIR, &vio, 1);
+    rc = pioctl(argv[2], _VICEIOCTL(_VIOC_REDIR), &vio, 1);
     if (rc <0) { PERROR("VIOC_REDIR"); }
 }
 
@@ -786,7 +767,7 @@ static void Disconnect(int argc, char *argv[], int opslot)
         vio.in_size = (int) (hcount * sizeof(unsigned long) + sizeof(int));
     }
 
-    rc = pioctl(mountpoint, VIOC_DISCONNECT, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_DISCONNECT), &vio, 1);
     if (rc < 0) { PERROR("VIOC_DISCONNECT"); exit(-1);}    
 
     if (insrv)
@@ -994,7 +975,7 @@ static int validateclosurespec(char *name, char *volname, char *volrootpath)
     vio.in_size = 0;
     vio.out = piobuf;
     vio.out_size = CFS_PIOBUFSIZE;
-    rc = pioctl(volrootpath, VIOCGETVOLSTAT, &vio, 1);
+    rc = pioctl(volrootpath, _VICEIOCTL(_VIOCGETVOLSTAT), &vio, 1);
     if (rc) { PERROR(volrootpath); return(0);}
 
     Volname = piobuf + sizeof(VolumeStatus);
@@ -1009,7 +990,7 @@ static int validateclosurespec(char *name, char *volname, char *volrootpath)
     vio.in_size = 0;
     vio.out = piobuf;
     vio.out_size = CFS_PIOBUFSIZE;
-    rc = pioctl(volrootpath, VIOC_GETFID, &vio, 1);
+    rc = pioctl(volrootpath, _VICEIOCTL(_VIOC_GETFID), &vio, 1);
     if (rc) { PERROR(volrootpath); return(0);}
     fid = (ViceFid *)piobuf;
     if (fid->Vnode != 1 || fid->Unique != 1)
@@ -1036,7 +1017,7 @@ static void FlushCache(int argc, char *argv[], int opslot)
     vio.in_size = 0;
     vio.out = 0;
     vio.out_size = 0;
-    rc = pioctl(mountpoint, VIOC_FLUSHCACHE, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_FLUSHCACHE), &vio, 1);
     if (rc < 0) { PERROR("VIOC_FLUSHCACHE"); exit(-1);}    
     }
 
@@ -1060,7 +1041,7 @@ static void FlushObject(int argc, char *argv[], int opslot)
         vio.in_size = 0;
         vio.out = 0;
         vio.out_size = 0;
-        rc = pioctl(argv[i], VIOCFLUSH, &vio, 0);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOCFLUSH), &vio, 0);
         if (rc < 0)
             {
             fflush(stdout);
@@ -1097,7 +1078,7 @@ static void FlushVolume(int argc, char *argv[], int opslot)
         vio.in_size = 0;
         vio.out = 0;
         vio.out_size = 0;
-        rc = pioctl(argv[i], VIOC_FLUSHVOLUME, &vio, 0);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOC_FLUSHVOLUME), &vio, 0);
         if (rc < 0) { PERROR("  VIOC_FLUSHVOLUME"); continue;}
         else {if (argc > 3) printf("\n");}
         }
@@ -1130,7 +1111,7 @@ static void BeginRepair(int argc, char *argv[], int opslot)
     vio.out = piobuf;
     memset(piobuf, 0, CFS_PIOBUFSIZE);
 
-    rc = pioctl(argv[2], VIOC_ENABLEREPAIR, &vio, 0);
+    rc = pioctl(argv[2], _VICEIOCTL(_VIOC_ENABLEREPAIR), &vio, 0);
     if (rc < 0) {
 	if (errno == EOPNOTSUPP) {
 	    fflush(stdout);
@@ -1157,7 +1138,7 @@ static void DisableASR(int argc, char *argv[], int opslot)
     vio.out = piobuf;
     memset(piobuf, 0, CFS_PIOBUFSIZE);
 
-    rc = pioctl(argv[2], VIOC_DISABLEASR, &vio, 0);
+    rc = pioctl(argv[2], _VICEIOCTL(_VIOC_DISABLEASR), &vio, 0);
     if (rc < 0) { PERROR("VIOC_DISABLEASR"); exit(-1); }
 }
 
@@ -1176,7 +1157,7 @@ static void EnableASR(int argc, char *argv[], int opslot)
     vio.out = piobuf;
     memset(piobuf, 0, CFS_PIOBUFSIZE);
 
-    rc = pioctl(argv[2], VIOC_ENABLEASR, &vio, 0);
+    rc = pioctl(argv[2], _VICEIOCTL(_VIOC_ENABLEASR), &vio, 0);
     if (rc < 0) { PERROR("VIOC_ENABLEASR"); exit(-1); }
 }
 
@@ -1195,7 +1176,7 @@ static void EndRepair(int argc, char *argv[], int opslot)
     vio.out = piobuf;
     memset(piobuf, 0, CFS_PIOBUFSIZE);
 
-    rc = pioctl(argv[2], VIOC_DISABLEREPAIR, &vio, 0);
+    rc = pioctl(argv[2], _VICEIOCTL(_VIOC_DISABLEREPAIR), &vio, 0);
     if (rc < 0) { PERROR("VIOC_DISABLEREPAIR"); exit(-1);}
 }
 
@@ -1220,7 +1201,7 @@ static void FlushASR(int argc, char *argv[], int opslot) {
         vio.out_size = CFS_PIOBUFSIZE;
         memset(piobuf, 0, CFS_PIOBUFSIZE);
 
-        rc = pioctl(argv[i], VIOC_FLUSHASR, &vio, 0);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOC_FLUSHASR), &vio, 0);
         if (rc < 0) { PERROR("VIOC_FLUSHASR"); continue; }
         printf("\n"); 
     }
@@ -1246,7 +1227,7 @@ static int pioctl_GetFid(char *path, ViceFid *fid, char *realm, ViceVersionVecto
 #if defined(DJGPP) || defined(__CYGWIN32__)
     rc = pioctl(path, 8972, &vio, 0);
 #else
-    rc = pioctl(path, VIOC_GETFID, &vio, 0);
+    rc = pioctl(path, _VICEIOCTL(_VIOC_GETFID), &vio, 0);
 #endif
 
     if (rc < 0) return rc;
@@ -1310,7 +1291,7 @@ static int pioctl_SetVV(char *path, ViceVersionVector *vv)
 #if defined(DJGPP) || defined(__CYGWIN32__)
     rc = pioctl(path, 8974, &vio, 0);
 #else
-    rc = pioctl(path, VIOC_SETVV, &vio, 0);
+    rc = pioctl(path, _VICEIOCTL(_VIOC_SETVV), &vio, 0);
 #endif
     return rc;
 }
@@ -1377,7 +1358,7 @@ static void GetPath(int argc, char *argv[], int opslot)
         vio.in_size = sizeof(ViceFid) + strlen(realmname) + 1;
         vio.out = piobuf;
         vio.out_size = CFS_PIOBUFSIZE;
-        rc = pioctl(mountpoint, VIOC_GETPATH, &vio, 0);
+        rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_GETPATH), &vio, 0);
         if (rc < 0) { PERROR("VIOC_GETPATH"); continue; }
         printf("\t%s\n", vio.out);
         }
@@ -1430,7 +1411,7 @@ static void ListACL(int argc, char *argv[], int opslot)
         vio.in_size = 0;
         vio.out_size = CFS_PIOBUFSIZE;
         vio.out = piobuf;
-        rc = pioctl(argv[i], VIOCGETAL, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOCGETAL), &vio, 1);
         if (rc < 0) { PERROR(argv[i]); continue; }
         
         if (argc > 3) printf("\n%s:\n", argv[i]); /* show directory name */
@@ -1606,7 +1587,7 @@ static void GetMountPoint(int argc, char *argv[], int opslot)
     vio.out_size = CFS_PIOBUFSIZE;
 
     /* Do the pioctl */
-    rc = pioctl(mountpoint, VIOC_GET_MT_PT, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_GET_MT_PT), &vio, 1);
     if (rc < 0) { PERROR("Failed in GetMountPoint."); exit(-1); }
     
     /* Print output field */
@@ -1700,7 +1681,7 @@ static void ListCache(int argc, char *argv[], int opslot)
         memset(piobuf, 0, CFS_PIOBUFSIZE);      
 
         /* Do the pioctl getting mount point pathname */
-        rc = pioctl(mountpoint, VIOC_GET_MT_PT, &vio, 1);
+        rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_GET_MT_PT), &vio, 1);
         if (rc < 0) { PERROR("Failed in GetMountPoint."); exit(-1); }
         strcpy(mtptpath, piobuf);
       }
@@ -1717,9 +1698,9 @@ static void ListCache(int argc, char *argv[], int opslot)
 
       /* Do the pioctl */
       if (vol_id)       /* VolumeId is specified. */
-        rc = pioctl(mtptpath, VIOC_LISTCACHE_VOLUME, &vio, 1);
+        rc = pioctl(mtptpath, _VICEIOCTL(_VIOC_LISTCACHE_VOLUME), &vio, 1);
       else              /* Mount point pathname is specified. */
-        rc = pioctl(argv[i], VIOC_LISTCACHE_VOLUME, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOC_LISTCACHE_VOLUME), &vio, 1);
       if (rc < 0) { PERROR(argv[i]); exit(-1); }
     }
   } else {
@@ -1736,7 +1717,7 @@ static void ListCache(int argc, char *argv[], int opslot)
       vio.out = piobuf;
       memset(piobuf, 0, CFS_PIOBUFSIZE);
       /* Do the pioctl */
-      rc = pioctl(mountpoint, VIOC_LISTCACHE, &vio, 1);
+      rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_LISTCACHE), &vio, 1);
       if (rc < 0) { PERROR("Failed in ListCache."); exit(-1); }
     }
 
@@ -1771,22 +1752,6 @@ static void ListCache(int argc, char *argv[], int opslot)
 }
 
 
-static int WriteBackStatus(char *vol)
-{
-  struct ViceIoctl vio;
-  int rc;
-  int cur;
-
-  vio.in = piobuf;
-  vio.in_size = 0;
-  vio.out = (char *) &cur;
-  vio.out_size = sizeof(int);
-  
-  rc = pioctl(vol, VIOC_STATUSWB, &vio, 0);
-  if (rc < 0) { PERROR("VIOC_STATUSWB"); exit(-1); }
-  return cur;
-}
-
 static void ListVolume(int argc, char *argv[], int opslot)
     {
     int i, rc;
@@ -1818,7 +1783,7 @@ static void ListVolume(int argc, char *argv[], int opslot)
         vio.out = piobuf;
 
         /* Do the pioctl */
-        rc = pioctl(argv[i], VIOCGETVOLSTAT, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOCGETVOLSTAT), &vio, 1);
         if (rc <0) { PERROR(argv[i]); continue; }
         
         /* Get pointers to output fields */
@@ -1859,12 +1824,6 @@ static void ListVolume(int argc, char *argv[], int opslot)
 	    printf("  The partition has %lu blocks available out of %lu\n",
 		   vs->PartBlocksAvail, vs->PartMaxBlocks);
 	}
-	printf("  Write-back is ");
-	if (WriteBackStatus(argv[i])) {
-	  printf("enabled\n");
-	} else {
-	  printf("disabled\n");
-	}
 	if (conflict)
 	    printf("  *** There are pending conflicts in this volume ***\n");
 	if (conn_state == Logging || conn_state == Emulating)
@@ -1902,12 +1861,30 @@ static void LookAside(int argc, char *argv[], int opslot)
         vio.out = piobuf;
         vio.out_size = CFS_PIOBUFSIZE;
 
-        rc = pioctl(mountpoint, VIOC_LOOKASIDE, &vio, 0);
+        rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_LOOKASIDE), &vio, 0);
         if (rc < 0) { PERROR("VIOC_LOOKASIDE"); return;}
 
 	if (piobuf[0]) printf("%s", piobuf); /* result of lka command */
     }
 
+static char *myrealpath(const char *path, char *buf, size_t size)
+{
+    char curdir[MAXPATHLEN+1], *s;
+    int rc;
+
+    s = getcwd(curdir, sizeof(curdir));
+    if (!s) return NULL;
+
+    rc = chdir(path);
+    if (rc < 0) return NULL;
+
+    s = getcwd(buf, size);
+
+    chdir(curdir);
+    return s;
+}
+
+
 static void LsMount (int argc, char *argv[], int opslot)
     /* This code will not detect a mount point where the root
        directory of the mounted volume denies permission for
@@ -1916,7 +1893,7 @@ static void LsMount (int argc, char *argv[], int opslot)
     {
     int i, rc, w; 
     struct ViceIoctl vio;
-    char part1[MAXPATHLEN], part2[MAXPATHLEN];
+    char path[MAXPATHLEN+1], tail[MAXNAMLEN+1];
     char *s;
     struct stat stbuf;
 
@@ -1952,28 +1929,27 @@ static void LsMount (int argc, char *argv[], int opslot)
 
 
         /* Next see if you can chdir to the target */
-        rc = chdir(argv[i]);
-        if (rc < 0)
-            {
-            if (errno == ENOTDIR) {printf("Not a mount point\n"); continue;}
-            else { PERROR("chdir"); continue; }
-            }
+	s = myrealpath(argv[i], path, sizeof(path));
+        if (rc < 0) {
+            if (errno == ENOTDIR)
+		fprintf(stderr, "%s - Not a mount point\n", argv[i]);
+            else
+		PERROR("realpath");
+	    continue;
+	}
 
-        /* We are in a directory, possibly the root of a volume */
-        s = getcwd(part1, MAXPATHLEN);
-        if (s == 0) { PERROR("getcwd"); continue; }
-        /* there must be a slash in what getcwd() returns */
-        s = rindex(part1, '/');
+        /* there must be a slash in what myrealpath() returns */
+        s = rindex(path, '/');
         *s = 0; /* lop off last component */
-        strcpy(part2, s+1); /* and copy it */
+        strncpy(tail, s+1, sizeof(tail)); /* and copy it */
 
         /* Ask Venus if this is a mount point */
-        vio.in = part2;
-        vio.in_size = (int) strlen(part2)+1;
+        vio.in = tail;
+        vio.in_size = (int) strlen(tail)+1;
         vio.out = piobuf;
         vio.out_size = CFS_PIOBUFSIZE;
         memset(piobuf, 0, CFS_PIOBUFSIZE);
-        rc = pioctl(part1, VIOC_AFS_STAT_MT_PT, &vio, 0);
+        rc = pioctl(path, _VICEIOCTL(_VIOC_AFS_STAT_MT_PT), &vio, 0);
         if (rc < 0)
             {
             if (errno == EINVAL || errno == ENOTDIR) {printf("Not a mount point\n"); continue;}
@@ -2014,7 +1990,7 @@ static void MkMount (int argc, char *argv[], int opslot)
     vio.in = buf;
     vio.out_size = 0;
     vio.out = 0;
-    rc = pioctl(dir, VIOC_ADD_MT_PT, &vio, 1);
+    rc = pioctl(dir, _VICEIOCTL(_VIOC_ADD_MT_PT), &vio, 1);
     if (rc < 0) { PERROR(dir); exit(-1); }
     }
 
@@ -2038,7 +2014,7 @@ static void PurgeML(int argc, char *argv[], int opslot)
     vio.in = 0;
     vio.out_size = 0;
     vio.out = 0;
-    rc = pioctl(codadir, VIOC_PURGEML, &vio, 1);
+    rc = pioctl(codadir, _VICEIOCTL(_VIOC_PURGEML), &vio, 1);
     if (rc) { PERROR("VIOC_PURGEML"); exit(-1); }
     }
 
@@ -2081,7 +2057,7 @@ static void Reconnect(int argc, char *argv[], int opslot)
         vio.in_size = (int) (hcount * sizeof(unsigned long) + sizeof(int));
     }
 
-    rc = pioctl(mountpoint, VIOC_RECONNECT, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_RECONNECT), &vio, 1);
     if (rc < 0) { PERROR("VIOC_RECONNECT"); exit(-1); } 
 
     if (insrv)
@@ -2162,7 +2138,7 @@ static void RmMount(int argc, char *argv[], int opslot)
         vio.in = suffix;
         vio.out_size = 0;
         vio.out = 0;
-        rc = pioctl(prefix, VIOC_AFS_DELETE_MT_PT, &vio, 0);
+        rc = pioctl(prefix, _VICEIOCTL(_VIOC_AFS_DELETE_MT_PT), &vio, 0);
         if (rc) { PERROR("VIOC_AFS_DELETE_MT_PT"); continue; }
         else {if (argc > 3) printf("\n");}
         }
@@ -2217,7 +2193,7 @@ static void SetACL (int argc, char *argv[], int opslot)
         vio.in_size = 0;
         vio.out_size = CFS_PIOBUFSIZE;
         vio.out = piobuf;
-        rc = pioctl(dir, VIOCGETAL, &vio, 1);
+        rc = pioctl(dir, _VICEIOCTL(_VIOCGETAL), &vio, 1);
         if (rc <0) { PERROR(dir); exit(-1); }
         rc = parseacl(vio.out, &a);
         if (rc < 0)
@@ -2291,7 +2267,7 @@ EntryDone:
     vio.in_size = (int) strlen(piobuf) + 1;
     vio.out_size = 0;
     vio.out = 0;
-    rc = pioctl(dir, VIOCSETAL, &vio, 1);
+    rc = pioctl(dir, _VICEIOCTL(_VIOCSETAL), &vio, 1);
     if (rc < 0) {
 	PERROR(dir);
 	if (errno == EINVAL)
@@ -2329,7 +2305,7 @@ static void SetQuota    (int argc, char *argv[], int opslot)
         vio.out = piobuf;
 
         /* Do the pioctl */
-        rc = pioctl(argv[i], VIOCGETVOLSTAT, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOCGETVOLSTAT), &vio, 1);
         if (rc <0) { PERROR(argv[i]); return; }
         
         /* Get pointers to output fields */
@@ -2344,12 +2320,12 @@ static void SetQuota    (int argc, char *argv[], int opslot)
         vio.out_size = CFS_PIOBUFSIZE;
         vio.out      = piobuf;
 
-        rc = pioctl(argv[i], VIOCSETVOLSTAT, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOCSETVOLSTAT), &vio, 1);
         if (rc <0) { PERROR("Setting new quota"); return; }
     }
 }
 
-#ifndef NDEBUG
+#ifdef UNUSED
 static void Slow(int argc, char *argv[], int opslot) 
 {
     int rc;
@@ -2366,7 +2342,7 @@ static void Slow(int argc, char *argv[], int opslot)
     vio.in_size = (int) sizeof(speed);
     vio.out = 0;
     vio.out_size = 0;
-    rc = pioctl(mountpoint, VIOC_SLOW, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_SLOW), &vio, 1);
     if (rc < 0){ PERROR("VIOC_SLOW"); exit(-1);}    
 }
 #endif
@@ -2385,7 +2361,7 @@ static void Strong(int argc, char *argv[], int opslot)
     vio.in_size = 0;
     vio.out = 0;
     vio.out_size = 0;
-    rc = pioctl(mountpoint, VIOC_STRONG, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_STRONG), &vio, 1);
     if (rc < 0){ PERROR("VIOC_STRONG"); exit(-1); }
 }
 
@@ -2403,7 +2379,7 @@ static void Adaptive(int argc, char *argv[], int opslot)
     vio.in_size = 0;
     vio.out = 0;
     vio.out_size = 0;
-    rc = pioctl(mountpoint, VIOC_ADAPTIVE, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_ADAPTIVE), &vio, 1);
     if (rc < 0){ PERROR("VIOC_ADAPTIVE"); exit(-1); } 
 }
 
@@ -2421,12 +2397,12 @@ static void TruncateLog(int argc, char *argv[], int opslot)
     vio.in_size = 0;
     vio.out = 0;
     vio.out_size = 0;
-    rc = pioctl(mountpoint, VIOC_TRUNCATELOG, &vio, 1);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_TRUNCATELOG), &vio, 1);
     if (rc < 0) { PERROR("  VIOC_TRUNCATELOG"); exit(-1); }
 }
 
 
-#ifndef NDEBUG
+#ifdef UNUSED
 static void Uncompress(int argc, char *argv[], int opslot)
 {
     int i, rc; 
@@ -2444,7 +2420,7 @@ static void Uncompress(int argc, char *argv[], int opslot)
         vio.in_size = 0;
         vio.out = 0;
         vio.out_size = 0;
-        rc = pioctl(argv[i], VIOC_UNCOMPRESS, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOC_UNCOMPRESS), &vio, 1);
         if (rc < 0) { PERROR("  VIOC_UNCOMPRESS"); continue; }
         if (argc > 3) printf("\n");
     }
@@ -2460,7 +2436,7 @@ static void UnloadKernel(int argc, char *argv[], int opslot)
     vio.in = 0;
     vio.out_size = 0;
     vio.out = 0;
-    rc = pioctl(mountpoint, VIOC_UNLOADKERNEL, &vio, 0);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_UNLOADKERNEL), &vio, 0);
     if (rc < 0) { PERROR("  VIOC_UNLOADKERNEL"); exit(-1); }
 }
 
@@ -2487,7 +2463,7 @@ static void WhereIs (int argc, char *argv[], int opslot)
         vio.out = piobuf;
 
         /* Do the pioctl */
-        rc = pioctl(argv[i], VIOCWHEREIS, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOCWHEREIS), &vio, 1);
         if (rc <0) { PERROR(argv[i]); continue; }
         
         /* Print custodians */
@@ -2537,7 +2513,7 @@ static void WaitForever (int argc, char *argv[], int opslot)
     vio.in_size = sizeof(arg);
     vio.out = 0;
     vio.out_size = 0;
-    rc = pioctl(mountpoint, VIOC_WAITFOREVER, &vio, 0);
+    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_WAITFOREVER), &vio, 0);
     if (rc < 0){ PERROR("VIOC_WAITFOREVER"); exit(-1); }
 }
 
@@ -2560,7 +2536,7 @@ static void WriteDisconnect(int argc, char *argv[], int opslot)
 
     if (argc == i)      /* no more args -- do them all */
         {
-        rc = pioctl(mountpoint, VIOC_WD_ALL, &vio, 1);     
+        rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_WD_ALL), &vio, 1);     
         if (rc) { PERROR("VIOC_WD_ALL"); exit(-1); }
         }
     else 
@@ -2570,104 +2546,12 @@ static void WriteDisconnect(int argc, char *argv[], int opslot)
             {
             if (argc > i+1) printf("  %*s\n", w, argv[j]); /* echo input if more than one fid */
 
-            rc = pioctl(argv[j], VIOC_BEGINML, &vio, 0);
+            rc = pioctl(argv[j], _VICEIOCTL(_VIOC_BEGINML), &vio, 0);
             if (rc < 0) { PERROR("VIOC_BEGINML"); exit(-1); }
             }
         }
     }
 
-static void WriteBackStart(int argc, char *argv[], int opslot)
-{
-  int  i = 2, rc, w;
-  struct ViceIoctl vio;
-  
-  if (argc < 3) {
-    printf("Usage: %s\n", cmdarray[opslot].usetxt);
-    exit(-1);
-  }
-  
-  w = getlongest(argc, argv);
-  
-  vio.in = piobuf;
-  vio.in_size = 0;
-  vio.out = 0;
-  vio.out_size = 0;
-  
-  for (i = 2; i < argc; i++) {
-    if (argc > 3) printf("  %*s:  ", w, argv[i]); /* echo input if more than one fid */
-    
-    rc = pioctl(argv[i], VIOC_BEGINWB, &vio, 0);
-    if (rc < 0) {
-	PERROR("VIOC_BEGINWB");
-	fprintf(stderr, "  return code : %d",rc);
-    }
-    else
-	printf("write-back enabled\n");
-  }
-}
-
-static void WriteBackStop(int argc, char *argv[], int opslot)
-{
-  int  i = 2, rc, w;
-  struct ViceIoctl vio;
-  
-  if (argc < 3) {
-    printf("Usage: %s\n", cmdarray[opslot].usetxt);
-    exit(-1);
-  }
-  
-  w = getlongest(argc, argv);
-  
-  vio.in = piobuf;
-  vio.in_size = 0;
-  vio.out = 0;
-  vio.out_size = 0;
-  
-  for (i = 2; i < argc; i++) {
-    if (argc > 3) printf("  %*s:  ", w, argv[i]); /* echo input if more than one fid */
-    
-    rc = pioctl(argv[i], VIOC_ENDWB, &vio, 0);
-    if (rc < 0) {
-	PERROR("VIOC_ENDWB");
-	fprintf(stderr, "  return code : %d",rc);
-    }
-    else
-	printf("write-back disabled\n");
-  }
-}
-
-static void WriteBackAuto(int argc, char *argv[], int opslot)
-{
-  int  i = 2, rc, w;
-  struct ViceIoctl vio;
-  
-  if (argc < 3) {
-    printf("Usage: %s\n", cmdarray[opslot].usetxt);
-    exit(-1);
-  }
-  
-  w = getlongest(argc, argv);
-  
-  vio.in = piobuf;
-  vio.in_size = 0;
-  vio.out = 0;
-  vio.out_size = 0;
-  
-  for (i = 2; i < argc; i++) {
-    if (argc > 3) printf("  %*s:  ", w, argv[i]); /* echo input if more than one fid */
-    
-    rc = pioctl(argv[i], VIOC_AUTOWB, &vio, 0);
-    if (rc < 0) {
-	PERROR("VIOC_AUTOWB");
-	fprintf(stderr, "  return code : %d",rc); 
-    }
-    else if (rc == WB_PERMIT_GRANTED)
-	printf("auto write-back enabled\n");
-    else
-	printf("auto write-back disabled\n");
-  }
-}
-
 static void ForceReintegrate(int argc, char *argv[], int opslot)
 {
   int  i = 2, rc, w;
@@ -2693,7 +2577,7 @@ static void ForceReintegrate(int argc, char *argv[], int opslot)
   for (i = 2; i < argc; i++) {
     if (argc > 3) printf("  %*s:  ", w, argv[i]); /* echo input if more than one fid */
     
-    rc = pioctl(argv[i], VIOC_SYNCCACHE, &vio, 0);
+    rc = pioctl(argv[i], _VICEIOCTL(_VIOC_SYNCCACHE), &vio, 0);
     fflush(stdout); 
     if (rc < 0) {
 	PERROR("VIOC_SYNCCACHE"); 
@@ -2706,7 +2590,7 @@ static void ForceReintegrate(int argc, char *argv[], int opslot)
         vio.out = piobuf;
 
         /* Do the pioctl */
-        rc = pioctl(argv[i], VIOCGETVOLSTAT, &vio, 1);
+        rc = pioctl(argv[i], _VICEIOCTL(_VIOCGETVOLSTAT), &vio, 1);
         if (rc < 0) {
 	    PERROR("VIOC_GETVOLSTAT");
 	    fprintf(stderr, "  VIOC_GETVOLSTAT returns %d\n", rc);
@@ -2751,7 +2635,7 @@ static void WriteReconnect(int argc, char *argv[], int opslot)
 
     if (argc == 2)      /* do them all */
         {
-        rc = pioctl(mountpoint, VIOC_WR_ALL, &vio, 1);     
+        rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_WR_ALL), &vio, 1);     
         if (rc) { PERROR("VIOC_WR_ALL"); exit(-1); }
         }    
     else 
@@ -2761,7 +2645,7 @@ static void WriteReconnect(int argc, char *argv[], int opslot)
             {
             if (argc > 3) printf("  %*s\n", w, argv[i]); /* echo input if more than one fid */
 
-            rc = pioctl(argv[i], VIOC_ENDML, &vio, 1);
+            rc = pioctl(argv[i], _VICEIOCTL(_VIOC_ENDML), &vio, 1);
             if (rc) { PERROR("VIOC_ENDML"); exit(-1); }
             }
         }
