@@ -37,11 +37,13 @@ Coda are listed in the file CREDITS.
 #endif
 
 #include <sys/types.h>
-#include <netinet/in.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
 #ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
@@ -164,8 +166,12 @@ static int parse_res_reply(char *answer, int alen,
 	    break; /* corrupted packet? */
 	}
 
-	if (name[0] == '.' && name[1] == '\0')
-	    continue;
+	/* according to the RFC, if there is a SRV record that has '.' as the
+	 * target, the service is decidedly not available at this domain */
+	if (name[0] == '.' && name[1] == '\0') {
+	    err = RPC2_EAI_NONAME;
+	    break;
+	}
 
 	tmperr = RPC2_getaddrinfo(name, NULL, hints, &cur);
 	if (!tmperr) {
@@ -181,11 +187,11 @@ static int parse_res_reply(char *answer, int alen,
 	    for (p = cur; p; p = p->ai_next) {
 		switch(p->ai_family) {
 		case PF_INET:
-		    ((struct sockaddr_in *)p->ai_addr)->sin_port = port;
+		    ((struct sockaddr_in *)p->ai_addr)->sin_port = htons(port);
 		    break;
 #ifdef PF_INET6
 		case PF_INET6:
-		    ((struct sockaddr_in6 *)p->ai_addr)->sin6_port = port;
+		    ((struct sockaddr_in6 *)p->ai_addr)->sin6_port = htons(port);
 		    break;
 #endif
 		}
@@ -195,7 +201,7 @@ static int parse_res_reply(char *answer, int alen,
 	    cur->ai_next = *res;
 	    *res = cur;
 	}
-	if (err == RPC2_EAI_AGAIN)
+	if (!err || err == RPC2_EAI_AGAIN)
 	    err = tmperr;
     }
     return err;
@@ -319,21 +325,16 @@ int coda_getaddrinfo(const char *node, const char *service,
 	initialized = 1;
     }
 
-    /* If the user specified hints, copy them. We might need to clear the
-     * CODA_AI_RES_SRV flag at some point */
-    if (hints) {
-	Hints = *hints;
-	hints = &Hints;
-    }
-
     err = RPC2_EAI_NONAME;
     if (hints && (hints->ai_flags & CODA_AI_RES_SRV))
     {
-#ifdef PF_INET6
 	char *end, tmp[sizeof(struct in6_addr)];
-#else
-	char *end, tmp[sizeof(struct in_addr)];
-#endif
+
+	/* We want to clear the CODA_AI_RES_SRV, but hints is const
+	 * so we make a copy */
+	Hints = *hints;
+	Hints.ai_flags &= ~CODA_AI_RES_SRV;
+	hints = &Hints;
 
 	/* we can only do an IN SRV record lookup if both node and
 	 * service are specified and not numerical */
@@ -349,19 +350,19 @@ int coda_getaddrinfo(const char *node, const char *service,
 #ifdef PF_INET6
 	/* check whether we were given an IP address in a format that doesn't
 	 * match the hinted address family */
-	if (hints->ai_family != PF_INET6 && inet_pton(PF_INET, node, &tmp) > 0)
-		return RPC2_EAI_BADFLAGS;
+	if (hints->ai_family == PF_INET6 && inet_pton(PF_INET, node, &tmp) > 0)
+	    return RPC2_EAI_BADFLAGS;
 
-	if (hints->ai_family != PF_INET && inet_pton(PF_INET6, node, &tmp) > 0)
+	if (hints->ai_family == PF_INET && inet_pton(PF_INET6, node, &tmp) > 0)
 	    return RPC2_EAI_BADFLAGS;
 #endif
 
-	/* lower layers don't really like unknown flagbits */
-	Hints.ai_flags &= ~CODA_AI_RES_SRV;
-
 #ifdef HAVE_RES_SEARCH
 	/* try to find SRV records */
 	err = do_srv_lookup(node, service, hints, &srvs);
+	if (err == RPC2_EAI_NONAME) /* found a SRV record with a '.' target? */
+	    goto Exit;
+
 	if (!err) {
 	    coda_reorder_addrinfo(&srvs);
 	    goto Exit;
@@ -369,8 +370,8 @@ int coda_getaddrinfo(const char *node, const char *service,
 #endif
     }
 
-    /* when not doing SRV record lookup or when it failed, we use
-     * a normal lookup */
+    /* when not doing SRV record lookup or when SRV lookup failed, we fall back
+     * to a normal lookup */
     err = RPC2_getaddrinfo(node, service, hints, &srvs);
     if (err == RPC2_EAI_SERVICE) {
 	fprintf(stderr, "Unable to map '%s' to a port, check /etc/services.\n",
