@@ -70,15 +70,14 @@ void SplitRealmFromName(char *name, char **realm)
 static void ResolveRootServers(char *servers, const char *service,
 			       struct RPC2_addrinfo **res)
 {
-    struct RPC2_addrinfo hints;
+    struct RPC2_addrinfo hints = {
+	.ai_family   = PF_INET,
+	.ai_socktype = SOCK_DGRAM,
+	.ai_protocol = IPPROTO_UDP,
+	.ai_flags    = RPC2_AI_CANONNAME,
+    };
     char *host;
 
-    memset(&hints, 0, sizeof(hints));
-    hints.ai_family   = PF_INET;
-    hints.ai_socktype = SOCK_DGRAM;
-    hints.ai_protocol = IPPROTO_UDP;
-    hints.ai_flags    = RPC2_AI_CANONNAME;
-
     while ((host = strtok(servers, ", \t\n")) != NULL)
     {
 	servers = NULL;
@@ -91,19 +90,21 @@ static void ResolveRootServers(char *servers, const char *service,
 static int isbadaddr(struct RPC2_addrinfo *ai, const char *name)
 {
     struct in_addr *ip;
+    unsigned long h_ip;
 
 #warning "assuming ipv4 only"
     if (ai->ai_family != PF_INET)
 	return 0;
 
     ip = &((struct sockaddr_in *)ai->ai_addr)->sin_addr;
+    h_ip = ntohl(ip->s_addr);
 
-    if (ntohl(ip->s_addr) == INADDR_ANY ||
-	ntohl(ip->s_addr) == INADDR_NONE ||
-	ntohl(ip->s_addr) == INADDR_LOOPBACK ||
-	(ntohl(ip->s_addr) & IN_CLASSA_NET) == IN_LOOPBACKNET ||
-	IN_MULTICAST(ntohl(ip->s_addr)) ||
-	IN_BADCLASS(ntohl(ip->s_addr)))
+    if (h_ip == INADDR_ANY ||
+	h_ip == INADDR_NONE ||
+	h_ip == INADDR_LOOPBACK ||
+	(h_ip & IN_CLASSA_NET) == IN_LOOPBACKNET ||
+	IN_MULTICAST(h_ip) ||
+	IN_BADCLASS(h_ip))
     {
 	fprintf(stderr, "An address in realm '%s' resolved to unusable address '%s', ignoring it\n", name, inet_ntoa(*ip));
 	return 1;
@@ -122,7 +123,8 @@ void GetRealmServers(const char *name, const char *service,
     if (!name || name[0] == '\0')
 	CODACONF_STR(name, "realm", "DEFAULT");
 
-    if (strcmp(name, "localhost") == 0)
+    if (!name || name[0] == '\0' || name[0] == '.' ||
+	strcmp(name, "localhost") == 0) /* is not a globally accessible realm */
 	return;
 
     CODACONF_STR(realmtab, "realmtab", SYSCONFDIR "/realms");
@@ -130,7 +132,7 @@ void GetRealmServers(const char *name, const char *service,
     f = fopen(realmtab, "r");
     if (f) {
 	namelen = strlen(name);
-	while (!found && fgets(line, MAXLINELEN, f))
+	while (fgets(line, MAXLINELEN, f))
 	{
 	    if (line[0] == '#') continue;
 
@@ -139,13 +141,19 @@ void GetRealmServers(const char *name, const char *service,
 	    {
 		ResolveRootServers(&line[namelen], service, &results);
 		found = 1;
+		break;
 	    }
 	}
 	fclose(f);
     }
 
     if (!found) {
-	struct RPC2_addrinfo hints;
+	struct RPC2_addrinfo hints = {
+	    .ai_family   = PF_INET,
+	    .ai_socktype = SOCK_DGRAM,
+	    .ai_protocol = IPPROTO_UDP,
+	    .ai_flags    = RPC2_AI_CANONNAME | CODA_AI_RES_SRV,
+	};
 
 #ifdef PF_INET6
 	/* As we expect only FQDNs, the name should contain at least one '.'
@@ -157,12 +165,6 @@ void GetRealmServers(const char *name, const char *service,
 	    if (strchr(name, '.') == NULL)
 		return;
 
-	memset(&hints, 0, sizeof(hints));
-	hints.ai_family   = PF_INET;
-	hints.ai_socktype = SOCK_DGRAM;
-	hints.ai_protocol = IPPROTO_UDP;
-	hints.ai_flags    = RPC2_AI_CANONNAME | CODA_AI_RES_SRV;
-
 	coda_getaddrinfo(name, service, &hints, &results);
     }
 
